{% extends 'dashboard/layout.html' %}
{% load category_tags %}
{% block body_class %}catalogue{% endblock %}

{% block title %}
{{ title }} | Category management | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url dashboard:index %}">Dashboard</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url dashboard:catalogue-category-list %}">Categories</a>
        <span class="divider">/</span>
    </li>
	<li class="active"><a href=".">{{ title }}</a></li>
</ul>
{% endblock %}

{% block header %}
<div class="page-header action">
	<h1>{{ title }}</h1>
</div>
{% endblock header %}

{% block dashboard_content %}
	<form action="." method="post" enctype="multipart/form-data">{% csrf_token %}
		{{ form.as_p }}
		<button type="submit" class="btn btn-primary btn-large">Save</button> or
		<a href="{% url dashboard:catalogue-category-list %}">cancel</a>
	</form>
{% endblock dashboard_content %}
