{% extends "layout.html" %}
{% load currency_filters %}
{% load thumbnail %}
{% load i18n %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url promotions:home %}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url customer:summary %}">{% trans 'Account' %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url customer:email-list %}">{% trans 'Email history' %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active"><a href=".">'{{ email.subject }}'</a></li>
</ul>
{% endblock %}


{% block title %}
{% trans 'Email detail' %} | {{ block.super }}
{% endblock %}

{% block header %}
<div class="page-header">
    <h2>{% trans 'Email:' %} '{{ email.subject }}'</h2>
</div>
{% endblock header %}


{% block content %}

<table class="table table-striped table-bordered">
    <tr>
        <th>{% trans 'Date sent' %}</th>
        <td>{{ email.date_sent }}</td>
    </tr>
    <tr>
        <th>{% trans 'Subject' %}</th>
        <td>{{ email.subject }}</td>
    </tr>
    <tr>
        <th>{% trans 'Body' %}</th>
        <td>{{ email.body_html|safe }}</td>
    </tr>
</table>

<div class="form-actions"><a href="{% url customer:email-list %}" class="btn">{% trans 'Return to email history' %}</a></div>

{% endblock content %}

