@import url("snowcone.css");
/*!
 * Bootstrap v2.0.0
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
nav,
section {
  display: block;
}
audio,
canvas,
video {
  display: inline-block;
  *display: inline;
  *zoom: 1;
}
audio:not([controls]) {
  display: none;
}
html {
  font-size: 100%;
  -webkit-text-size-adjust: 100%;
  -ms-text-size-adjust: 100%;
}
a:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
a:hover,
a:active {
  outline: 0;
}
sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
}
sup {
  top: -0.5em;
}
sub {
  bottom: -0.25em;
}
img {
  max-width: 100%;
  height: auto;
  border: 0;
  -ms-interpolation-mode: bicubic;
}
button,
input,
select,
textarea {
  margin: 0;
  font-size: 100%;
  vertical-align: middle;
}
button,
input {
  *overflow: visible;
  line-height: normal;
}
button::-moz-focus-inner,
input::-moz-focus-inner {
  padding: 0;
  border: 0;
}
button,
input[type="button"],
input[type="reset"],
input[type="submit"] {
  cursor: pointer;
  -webkit-appearance: button;
}
input[type="search"] {
  -webkit-appearance: textfield;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
input[type="search"]::-webkit-search-decoration,
input[type="search"]::-webkit-search-cancel-button {
  -webkit-appearance: none;
}
textarea {
  overflow: auto;
  vertical-align: top;
}
body {
  margin: 0;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 13px;
  line-height: 18px;
  color: #333333;
  background-color: #ffffff;
}
a {
  color: #0088cc;
  text-decoration: none;
}
a:hover {
  color: #005580;
  text-decoration: underline;
}
.row {
  margin-left: -20px;
  *zoom: 1;
}
.row:before,
.row:after {
  display: table;
  content: "";
}
.row:after {
  clear: both;
}
[class*="span"] {
  float: left;
  margin-left: 20px;
}
.span1 {
  width: 60px;
}
.span2 {
  width: 140px;
}
.span3 {
  width: 220px;
}
.span4 {
  width: 300px;
}
.span5 {
  width: 380px;
}
.span6 {
  width: 460px;
}
.span7 {
  width: 540px;
}
.span8 {
  width: 620px;
}
.span9 {
  width: 700px;
}
.span10 {
  width: 780px;
}
.span11 {
  width: 860px;
}
.span12,
.container {
  width: 940px;
}
.offset1 {
  margin-left: 100px;
}
.offset2 {
  margin-left: 180px;
}
.offset3 {
  margin-left: 260px;
}
.offset4 {
  margin-left: 340px;
}
.offset5 {
  margin-left: 420px;
}
.offset6 {
  margin-left: 500px;
}
.offset7 {
  margin-left: 580px;
}
.offset8 {
  margin-left: 660px;
}
.offset9 {
  margin-left: 740px;
}
.offset10 {
  margin-left: 820px;
}
.offset11 {
  margin-left: 900px;
}
.row-fluid {
  width: 100%;
  *zoom: 1;
}
.row-fluid:before,
.row-fluid:after {
  display: table;
  content: "";
}
.row-fluid:after {
  clear: both;
}
.row-fluid > [class*="span"] {
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid > [class*="span"]:first-child {
  margin-left: 0;
}
.row-fluid .span1 {
  width: 6.382978723%;
}
.row-fluid .span2 {
  width: 14.89361702%;
}
.row-fluid .span3 {
  width: 23.404255317%;
}
.row-fluid .span4 {
  width: 31.914893614%;
}
.row-fluid .span5 {
  width: 40.425531911%;
}
.row-fluid .span6 {
  width: 48.93617020799999%;
}
.row-fluid .span7 {
  width: 57.446808505%;
}
.row-fluid .span8 {
  width: 65.95744680199999%;
}
.row-fluid .span9 {
  width: 74.468085099%;
}
.row-fluid .span10 {
  width: 82.97872339599999%;
}
.row-fluid .span11 {
  width: 91.489361693%;
}
.row-fluid .span12 {
  width: 99.99999998999999%;
}
.container {
  width: 940px;
  margin-left: auto;
  margin-right: auto;
  *zoom: 1;
}
.container:before,
.container:after {
  display: table;
  content: "";
}
.container:after {
  clear: both;
}
.container-fluid {
  padding-left: 20px;
  padding-right: 20px;
  *zoom: 1;
}
.container-fluid:before,
.container-fluid:after {
  display: table;
  content: "";
}
.container-fluid:after {
  clear: both;
}
p {
  margin: 0 0 9px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 13px;
  line-height: 18px;
}
p small {
  font-size: 11px;
  color: #999999;
}
.lead {
  margin-bottom: 18px;
  font-size: 20px;
  font-weight: 200;
  line-height: 27px;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  margin: 0;
  font-weight: bold;
  color: #333333;
  text-rendering: optimizelegibility;
}
h1 small,
h2 small,
h3 small,
h4 small,
h5 small,
h6 small {
  font-weight: normal;
  color: #999999;
}
h1 {
  font-size: 30px;
  line-height: 36px;
}
h1 small {
  font-size: 18px;
}
h2 {
  font-size: 24px;
  line-height: 36px;
}
h2 small {
  font-size: 18px;
}
h3 {
  line-height: 27px;
  font-size: 18px;
}
h3 small {
  font-size: 14px;
}
h4,
h5,
h6 {
  line-height: 18px;
}
h4 {
  font-size: 14px;
}
h4 small {
  font-size: 12px;
}
h5 {
  font-size: 12px;
}
h6 {
  font-size: 11px;
  color: #999999;
  text-transform: uppercase;
}
.page-header {
  padding-bottom: 17px;
  margin: 18px 0;
  border-bottom: 1px solid #eeeeee;
}
.page-header h1 {
  line-height: 1;
}
ul,
ol {
  padding: 0;
  margin: 0 0 9px 25px;
}
ul ul,
ul ol,
ol ol,
ol ul {
  margin-bottom: 0;
}
ul {
  list-style: disc;
}
ol {
  list-style: decimal;
}
li {
  line-height: 18px;
}
ul.unstyled {
  margin-left: 0;
  list-style: none;
}
dl {
  margin-bottom: 18px;
}
dt,
dd {
  line-height: 18px;
}
dt {
  font-weight: bold;
}
dd {
  margin-left: 9px;
}
hr {
  margin: 18px 0;
  border: 0;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #ffffff;
}
strong {
  font-weight: bold;
}
em {
  font-style: italic;
}
.muted {
  color: #999999;
}
abbr {
  font-size: 90%;
  text-transform: uppercase;
  border-bottom: 1px dotted #ddd;
  cursor: help;
}
blockquote {
  padding: 0 0 0 15px;
  margin: 0 0 18px;
  border-left: 5px solid #eeeeee;
}
blockquote p {
  margin-bottom: 0;
  font-size: 16px;
  font-weight: 300;
  line-height: 22.5px;
}
blockquote small {
  display: block;
  line-height: 18px;
  color: #999999;
}
blockquote small:before {
  content: '\2014 \00A0';
}
blockquote.pull-right {
  float: right;
  padding-left: 0;
  padding-right: 15px;
  border-left: 0;
  border-right: 5px solid #eeeeee;
}
blockquote.pull-right p,
blockquote.pull-right small {
  text-align: right;
}
q:before,
q:after,
blockquote:before,
blockquote:after {
  content: "";
}
address {
  display: block;
  margin-bottom: 18px;
  line-height: 18px;
  font-style: normal;
}
small {
  font-size: 100%;
}
cite {
  font-style: normal;
}
form {
  margin: 0 0 18px;
}
fieldset {
  padding: 0;
  margin: 0;
  border: 0;
}
legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 27px;
  font-size: 19.5px;
  line-height: 36px;
  color: #333333;
  border: 0;
  border-bottom: 1px solid #eee;
}
label,
input,
button,
select,
textarea {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 13px;
  font-weight: normal;
  line-height: 18px;
}
label {
  display: block;
  margin-bottom: 5px;
  color: #333333;
}
input,
textarea,
select,
.uneditable-input {
  display: inline-block;
  width: 210px;
  height: 18px;
  padding: 4px;
  margin-bottom: 9px;
  font-size: 13px;
  line-height: 18px;
  color: #555555;
  border: 1px solid #ccc;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.uneditable-textarea {
  width: auto;
  height: auto;
}
label input,
label textarea,
label select {
  display: block;
}
input[type="image"],
input[type="checkbox"],
input[type="radio"] {
  width: auto;
  height: auto;
  padding: 0;
  margin: 3px 0;
  *margin-top: 0;
  /* IE7 */

  line-height: normal;
  border: 0;
  cursor: pointer;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
input[type="file"] {
  padding: initial;
  line-height: initial;
  border: initial;
  background-color: #ffffff;
  background-color: initial;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
input[type="button"],
input[type="reset"],
input[type="submit"] {
  width: auto;
  height: auto;
}
select,
input[type="file"] {
  height: 28px;
  /* In IE7, the height of the select element cannot be changed by height, only font-size */

  *margin-top: 4px;
  /* For IE7, add top margin to align select with labels */

  line-height: 28px;
}
select {
  width: 220px;
  background-color: #ffffff;
}
select[multiple],
select[size] {
  height: auto;
}
input[type="image"] {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
textarea {
  height: auto;
}
input[type="hidden"] {
  display: none;
}
.radio,
.checkbox {
  padding-left: 18px;
}
.radio input[type="radio"],
.checkbox input[type="checkbox"] {
  float: left;
  margin-left: -18px;
}
.controls > .radio:first-child,
.controls > .checkbox:first-child {
  padding-top: 5px;
}
.radio.inline,
.checkbox.inline {
  display: inline-block;
  margin-bottom: 0;
  vertical-align: middle;
}
.radio.inline + .radio.inline,
.checkbox.inline + .checkbox.inline {
  margin-left: 10px;
}
.controls > .radio.inline:first-child,
.controls > .checkbox.inline:first-child {
  padding-top: 0;
}
input,
textarea {
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border linear 0.2s, box-shadow linear 0.2s;
  -moz-transition: border linear 0.2s, box-shadow linear 0.2s;
  -ms-transition: border linear 0.2s, box-shadow linear 0.2s;
  -o-transition: border linear 0.2s, box-shadow linear 0.2s;
  transition: border linear 0.2s, box-shadow linear 0.2s;
}
input:focus,
textarea:focus {
  border-color: rgba(82, 168, 236, 0.8);
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
  outline: 0;
  outline: thin dotted \9;
  /* IE6-8 */

}
input[type="file"]:focus,
input[type="checkbox"]:focus,
select:focus {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.input-mini {
  width: 60px;
}
.input-small {
  width: 90px;
}
.input-medium {
  width: 150px;
}
.input-large {
  width: 210px;
}
.input-xlarge {
  width: 270px;
}
.input-xxlarge {
  width: 530px;
}
input[class*="span"],
select[class*="span"],
textarea[class*="span"],
.uneditable-input {
  float: none;
  margin-left: 0;
}
input.span1,
textarea.span1,
.uneditable-input.span1 {
  width: 50px;
}
input.span2,
textarea.span2,
.uneditable-input.span2 {
  width: 130px;
}
input.span3,
textarea.span3,
.uneditable-input.span3 {
  width: 210px;
}
input.span4,
textarea.span4,
.uneditable-input.span4 {
  width: 290px;
}
input.span5,
textarea.span5,
.uneditable-input.span5 {
  width: 370px;
}
input.span6,
textarea.span6,
.uneditable-input.span6 {
  width: 450px;
}
input.span7,
textarea.span7,
.uneditable-input.span7 {
  width: 530px;
}
input.span8,
textarea.span8,
.uneditable-input.span8 {
  width: 610px;
}
input.span9,
textarea.span9,
.uneditable-input.span9 {
  width: 690px;
}
input.span10,
textarea.span10,
.uneditable-input.span10 {
  width: 770px;
}
input.span11,
textarea.span11,
.uneditable-input.span11 {
  width: 850px;
}
input.span12,
textarea.span12,
.uneditable-input.span12 {
  width: 930px;
}
input[disabled],
select[disabled],
textarea[disabled],
input[readonly],
select[readonly],
textarea[readonly] {
  background-color: #f5f5f5;
  border-color: #ddd;
  cursor: not-allowed;
}
.control-group.warning > label,
.control-group.warning .help-block,
.control-group.warning .help-inline {
  color: #c09853;
}
.control-group.warning input,
.control-group.warning select,
.control-group.warning textarea {
  color: #c09853;
  border-color: #c09853;
}
.control-group.warning input:focus,
.control-group.warning select:focus,
.control-group.warning textarea:focus {
  border-color: #a47e3c;
  -webkit-box-shadow: 0 0 6px #dbc59e;
  -moz-box-shadow: 0 0 6px #dbc59e;
  box-shadow: 0 0 6px #dbc59e;
}
.control-group.warning .input-prepend .add-on,
.control-group.warning .input-append .add-on {
  color: #c09853;
  background-color: #fcf8e3;
  border-color: #c09853;
}
.control-group.error > label,
.control-group.error .help-block,
.control-group.error .help-inline {
  color: #b94a48;
}
.control-group.error input,
.control-group.error select,
.control-group.error textarea {
  color: #b94a48;
  border-color: #b94a48;
}
.control-group.error input:focus,
.control-group.error select:focus,
.control-group.error textarea:focus {
  border-color: #953b39;
  -webkit-box-shadow: 0 0 6px #d59392;
  -moz-box-shadow: 0 0 6px #d59392;
  box-shadow: 0 0 6px #d59392;
}
.control-group.error .input-prepend .add-on,
.control-group.error .input-append .add-on {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #b94a48;
}
.control-group.success > label,
.control-group.success .help-block,
.control-group.success .help-inline {
  color: #468847;
}
.control-group.success input,
.control-group.success select,
.control-group.success textarea {
  color: #468847;
  border-color: #468847;
}
.control-group.success input:focus,
.control-group.success select:focus,
.control-group.success textarea:focus {
  border-color: #356635;
  -webkit-box-shadow: 0 0 6px #7aba7b;
  -moz-box-shadow: 0 0 6px #7aba7b;
  box-shadow: 0 0 6px #7aba7b;
}
.control-group.success .input-prepend .add-on,
.control-group.success .input-append .add-on {
  color: #468847;
  background-color: #dff0d8;
  border-color: #468847;
}
input:focus:required:invalid,
textarea:focus:required:invalid,
select:focus:required:invalid {
  color: #b94a48;
  border-color: #ee5f5b;
}
input:focus:required:invalid:focus,
textarea:focus:required:invalid:focus,
select:focus:required:invalid:focus {
  border-color: #e9322d;
  -webkit-box-shadow: 0 0 6px #f8b9b7;
  -moz-box-shadow: 0 0 6px #f8b9b7;
  box-shadow: 0 0 6px #f8b9b7;
}
.form-actions {
  padding: 17px 20px 18px;
  margin-top: 18px;
  margin-bottom: 18px;
  background-color: #f5f5f5;
  border-top: 1px solid #ddd;
}
.uneditable-input {
  display: block;
  background-color: #ffffff;
  border-color: #eee;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
  cursor: not-allowed;
}
:-moz-placeholder {
  color: #999999;
}
::-webkit-input-placeholder {
  color: #999999;
}
.help-block {
  margin-top: 5px;
  margin-bottom: 0;
  color: #999999;
}
.help-inline {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */

  *zoom: 1;
  margin-bottom: 9px;
  vertical-align: middle;
  padding-left: 5px;
}
.input-prepend,
.input-append {
  margin-bottom: 5px;
  *zoom: 1;
}
.input-prepend:before,
.input-append:before,
.input-prepend:after,
.input-append:after {
  display: table;
  content: "";
}
.input-prepend:after,
.input-append:after {
  clear: both;
}
.input-prepend input,
.input-append input,
.input-prepend .uneditable-input,
.input-append .uneditable-input {
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-prepend input:focus,
.input-append input:focus,
.input-prepend .uneditable-input:focus,
.input-append .uneditable-input:focus {
  position: relative;
  z-index: 2;
}
.input-prepend .uneditable-input,
.input-append .uneditable-input {
  border-left-color: #ccc;
}
.input-prepend .add-on,
.input-append .add-on {
  float: left;
  display: block;
  width: auto;
  min-width: 16px;
  height: 18px;
  margin-right: -1px;
  padding: 4px 5px;
  font-weight: normal;
  line-height: 18px;
  color: #999999;
  text-align: center;
  text-shadow: 0 1px 0 #ffffff;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
}
.input-prepend .active,
.input-append .active {
  background-color: #a9dba9;
  border-color: #46a546;
}
.input-prepend .add-on {
  *margin-top: 1px;
  /* IE6-7 */

}
.input-append input,
.input-append .uneditable-input {
  float: left;
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
}
.input-append .uneditable-input {
  border-right-color: #ccc;
}
.input-append .add-on {
  margin-right: 0;
  margin-left: -1px;
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}
.input-append input:first-child {
  *margin-left: -160px;
}
.input-append input:first-child + .add-on {
  *margin-left: -21px;
}
.search-query {
  padding-left: 14px;
  padding-right: 14px;
  margin-bottom: 0;
  -webkit-border-radius: 14px;
  -moz-border-radius: 14px;
  border-radius: 14px;
}
.form-search input,
.form-inline input,
.form-horizontal input,
.form-search textarea,
.form-inline textarea,
.form-horizontal textarea,
.form-search select,
.form-inline select,
.form-horizontal select,
.form-search .help-inline,
.form-inline .help-inline,
.form-horizontal .help-inline,
.form-search .uneditable-input,
.form-inline .uneditable-input,
.form-horizontal .uneditable-input {
  display: inline-block;
  margin-bottom: 0;
}
.form-search label,
.form-inline label,
.form-search .input-append,
.form-inline .input-append,
.form-search .input-prepend,
.form-inline .input-prepend {
  display: inline-block;
}
.form-search .input-append .add-on,
.form-inline .input-prepend .add-on,
.form-search .input-append .add-on,
.form-inline .input-prepend .add-on {
  vertical-align: middle;
}
.control-group {
  margin-bottom: 9px;
}
.form-horizontal legend + .control-group {
  margin-top: 18px;
  -webkit-margin-top-collapse: separate;
}
.form-horizontal .control-group {
  margin-bottom: 18px;
  *zoom: 1;
}
.form-horizontal .control-group:before,
.form-horizontal .control-group:after {
  display: table;
  content: "";
}
.form-horizontal .control-group:after {
  clear: both;
}
.form-horizontal .control-group > label {
  float: left;
  width: 140px;
  padding-top: 5px;
  text-align: right;
}
.form-horizontal .controls {
  margin-left: 160px;
}
.form-horizontal .form-actions {
  padding-left: 160px;
}
table {
  max-width: 100%;
  border-collapse: collapse;
  border-spacing: 0;
}
.table {
  width: 100%;
  margin-bottom: 18px;
}
.table th,
.table td {
  padding: 8px;
  line-height: 18px;
  text-align: left;
  border-top: 1px solid #ddd;
}
.table th {
  font-weight: bold;
  vertical-align: bottom;
}
.table td {
  vertical-align: top;
}
.table thead:first-child tr th,
.table thead:first-child tr td {
  border-top: 0;
}
.table tbody + tbody {
  border-top: 2px solid #ddd;
}
.table-condensed th,
.table-condensed td {
  padding: 4px 5px;
}
.table-bordered {
  border: 1px solid #ddd;
  border-collapse: separate;
  *border-collapse: collapsed;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.table-bordered th + th,
.table-bordered td + td,
.table-bordered th + td,
.table-bordered td + th {
  border-left: 1px solid #ddd;
}
.table-bordered thead:first-child tr:first-child th,
.table-bordered tbody:first-child tr:first-child th,
.table-bordered tbody:first-child tr:first-child td {
  border-top: 0;
}
.table-bordered thead:first-child tr:first-child th:first-child,
.table-bordered tbody:first-child tr:first-child td:first-child {
  -webkit-border-radius: 4px 0 0 0;
  -moz-border-radius: 4px 0 0 0;
  border-radius: 4px 0 0 0;
}
.table-bordered thead:first-child tr:first-child th:last-child,
.table-bordered tbody:first-child tr:first-child td:last-child {
  -webkit-border-radius: 0 4px 0 0;
  -moz-border-radius: 0 4px 0 0;
  border-radius: 0 4px 0 0;
}
.table-bordered thead:last-child tr:last-child th:first-child,
.table-bordered tbody:last-child tr:last-child td:first-child {
  -webkit-border-radius: 0 0 0 4px;
  -moz-border-radius: 0 0 0 4px;
  border-radius: 0 0 0 4px;
}
.table-bordered thead:last-child tr:last-child th:last-child,
.table-bordered tbody:last-child tr:last-child td:last-child {
  -webkit-border-radius: 0 0 4px 0;
  -moz-border-radius: 0 0 4px 0;
  border-radius: 0 0 4px 0;
}
.table-striped tbody tr:nth-child(odd) td,
.table-striped tbody tr:nth-child(odd) th {
  background-color: #f9f9f9;
}
table .span1 {
  float: none;
  width: 44px;
  margin-left: 0;
}
table .span2 {
  float: none;
  width: 124px;
  margin-left: 0;
}
table .span3 {
  float: none;
  width: 204px;
  margin-left: 0;
}
table .span4 {
  float: none;
  width: 284px;
  margin-left: 0;
}
table .span5 {
  float: none;
  width: 364px;
  margin-left: 0;
}
table .span6 {
  float: none;
  width: 444px;
  margin-left: 0;
}
table .span7 {
  float: none;
  width: 524px;
  margin-left: 0;
}
table .span8 {
  float: none;
  width: 604px;
  margin-left: 0;
}
table .span9 {
  float: none;
  width: 684px;
  margin-left: 0;
}
table .span10 {
  float: none;
  width: 764px;
  margin-left: 0;
}
table .span11 {
  float: none;
  width: 844px;
  margin-left: 0;
}
table .span12 {
  float: none;
  width: 924px;
  margin-left: 0;
}
.dropdown {
  position: relative;
}
.dropdown-toggle {
  *margin-bottom: -3px;
}
.dropdown-toggle:active,
.open .dropdown-toggle {
  outline: 0;
}
.caret {
  display: inline-block;
  width: 0;
  height: 0;
  text-indent: -99999px;
  *text-indent: 0;
  vertical-align: top;
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid #000000;
  opacity: 0.3;
  filter: alpha(opacity=30);
  content: "\2193";
}
.dropdown .caret {
  margin-top: 8px;
  margin-left: 2px;
}
.dropdown:hover .caret,
.open.dropdown .caret {
  opacity: 1;
  filter: alpha(opacity=100);
}
.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  float: left;
  display: none;
  min-width: 160px;
  max-width: 220px;
  _width: 160px;
  padding: 4px 0;
  margin: 0;
  list-style: none;
  background-color: #ffffff;
  border-color: #ccc;
  border-color: rgba(0, 0, 0, 0.2);
  border-style: solid;
  border-width: 1px;
  -webkit-border-radius: 0 0 5px 5px;
  -moz-border-radius: 0 0 5px 5px;
  border-radius: 0 0 5px 5px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding;
  background-clip: padding-box;
  *border-right-width: 2px;
  *border-bottom-width: 2px;
}
.dropdown-menu.bottom-up {
  top: auto;
  bottom: 100%;
  margin-bottom: 2px;
}
.dropdown-menu .divider {
  height: 1px;
  margin: 5px 1px;
  overflow: hidden;
  background-color: #e5e5e5;
  border-bottom: 1px solid #ffffff;
  *width: 100%;
  *margin: -5px 0 5px;
}
.dropdown-menu a {
  display: block;
  padding: 3px 15px;
  clear: both;
  font-weight: normal;
  line-height: 18px;
  color: #555555;
  white-space: nowrap;
}
.dropdown-menu li > a:hover,
.dropdown-menu .active > a,
.dropdown-menu .active > a:hover {
  color: #ffffff;
  text-decoration: none;
  background-color: #0088cc;
}
.dropdown.open {
  *z-index: 1000;
}
.dropdown.open .dropdown-toggle {
  color: #ffffff;
  background: #ccc;
  background: rgba(0, 0, 0, 0.3);
}
.dropdown.open .dropdown-menu {
  display: block;
}
.typeahead {
  margin-top: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.well {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #eee;
  border: 1px solid rgba(0, 0, 0, 0.05);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
}
.well blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.fade {
  -webkit-transition: opacity 0.15s linear;
  -moz-transition: opacity 0.15s linear;
  -ms-transition: opacity 0.15s linear;
  -o-transition: opacity 0.15s linear;
  transition: opacity 0.15s linear;
  opacity: 0;
}
.fade.in {
  opacity: 1;
}
.collapse {
  -webkit-transition: height 0.35s ease;
  -moz-transition: height 0.35s ease;
  -ms-transition: height 0.35s ease;
  -o-transition: height 0.35s ease;
  transition: height 0.35s ease;
  position: relative;
  overflow: hidden;
  height: 0;
}
.collapse.in {
  height: auto;
}
.close {
  float: right;
  font-size: 20px;
  font-weight: bold;
  line-height: 18px;
  color: #000000;
  text-shadow: 0 1px 0 #ffffff;
  opacity: 0.2;
  filter: alpha(opacity=20);
}
.close:hover {
  color: #000000;
  text-decoration: none;
  opacity: 0.4;
  filter: alpha(opacity=40);
  cursor: pointer;
}
.btn {
  display: inline-block;
  padding: 4px 10px 4px;
  font-size: 13px;
  line-height: 18px;
  color: #333333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  background-color: #fafafa;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), color-stop(25%, #ffffff), to(#e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-image: -moz-linear-gradient(top, #ffffff, #ffffff 25%, #e6e6e6);
  background-image: -ms-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-image: linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-repeat: no-repeat;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
  border: 1px solid #ccc;
  border-bottom-color: #bbb;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  cursor: pointer;
  *margin-left: .3em;
}
.btn:first-child {
  *margin-left: 0;
}
.btn:hover {
  color: #333333;
  text-decoration: none;
  background-color: #e6e6e6;
  background-position: 0 -15px;
  -webkit-transition: background-position 0.1s linear;
  -moz-transition: background-position 0.1s linear;
  -ms-transition: background-position 0.1s linear;
  -o-transition: background-position 0.1s linear;
  transition: background-position 0.1s linear;
}
.btn:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.btn.active,
.btn:active {
  background-image: none;
  -webkit-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  background-color: #e6e6e6;
  background-color: #d9d9d9 \9;
  color: rgba(0, 0, 0, 0.5);
  outline: 0;
}
.btn.disabled,
.btn[disabled] {
  cursor: default;
  background-image: none;
  background-color: #e6e6e6;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
.btn-large {
  padding: 9px 14px;
  font-size: 15px;
  line-height: normal;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.btn-large .icon {
  margin-top: 1px;
}
.btn-small {
  padding: 5px 9px;
  font-size: 11px;
  line-height: 16px;
}
.btn-small .icon {
  margin-top: -1px;
}
.btn-primary,
.btn-primary:hover,
.btn-warning,
.btn-warning:hover,
.btn-danger,
.btn-danger:hover,
.btn-success,
.btn-success:hover,
.btn-info,
.btn-info:hover {
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  color: #ffffff;
}
.btn-primary.active,
.btn-warning.active,
.btn-danger.active,
.btn-success.active,
.btn-info.active {
  color: rgba(255, 255, 255, 0.75);
}
.btn-primary {
  background-color: #006dcc;
  background-image: -moz-linear-gradient(top, #0088cc, #0044cc);
  background-image: -ms-linear-gradient(top, #0088cc, #0044cc);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0088cc), to(#0044cc));
  background-image: -webkit-linear-gradient(top, #0088cc, #0044cc);
  background-image: -o-linear-gradient(top, #0088cc, #0044cc);
  background-image: linear-gradient(top, #0088cc, #0044cc);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0088cc', endColorstr='#0044cc', GradientType=0);
  border-color: #0044cc #0044cc #002a80;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-primary:hover,
.btn-primary:active,
.btn-primary.active,
.btn-primary.disabled,
.btn-primary[disabled] {
  background-color: #0044cc;
}
.btn-primary:active,
.btn-primary.active {
  background-color: #003399 \9;
}
.btn-warning {
  background-color: #faa732;
  background-image: -moz-linear-gradient(top, #fbb450, #f89406);
  background-image: -ms-linear-gradient(top, #fbb450, #f89406);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fbb450), to(#f89406));
  background-image: -webkit-linear-gradient(top, #fbb450, #f89406);
  background-image: -o-linear-gradient(top, #fbb450, #f89406);
  background-image: linear-gradient(top, #fbb450, #f89406);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fbb450', endColorstr='#f89406', GradientType=0);
  border-color: #f89406 #f89406 #ad6704;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-warning:hover,
.btn-warning:active,
.btn-warning.active,
.btn-warning.disabled,
.btn-warning[disabled] {
  background-color: #f89406;
}
.btn-warning:active,
.btn-warning.active {
  background-color: #c67605 \9;
}
.btn-danger {
  background-color: #da4f49;
  background-image: -moz-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: -ms-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ee5f5b), to(#bd362f));
  background-image: -webkit-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: -o-linear-gradient(top, #ee5f5b, #bd362f);
  background-image: linear-gradient(top, #ee5f5b, #bd362f);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ee5f5b', endColorstr='#bd362f', GradientType=0);
  border-color: #bd362f #bd362f #802420;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-danger:hover,
.btn-danger:active,
.btn-danger.active,
.btn-danger.disabled,
.btn-danger[disabled] {
  background-color: #bd362f;
}
.btn-danger:active,
.btn-danger.active {
  background-color: #942a25 \9;
}
.btn-success {
  background-color: #5bb75b;
  background-image: -moz-linear-gradient(top, #62c462, #51a351);
  background-image: -ms-linear-gradient(top, #62c462, #51a351);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#62c462), to(#51a351));
  background-image: -webkit-linear-gradient(top, #62c462, #51a351);
  background-image: -o-linear-gradient(top, #62c462, #51a351);
  background-image: linear-gradient(top, #62c462, #51a351);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#62c462', endColorstr='#51a351', GradientType=0);
  border-color: #51a351 #51a351 #387038;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-success:hover,
.btn-success:active,
.btn-success.active,
.btn-success.disabled,
.btn-success[disabled] {
  background-color: #51a351;
}
.btn-success:active,
.btn-success.active {
  background-color: #408140 \9;
}
.btn-info {
  background-color: #49afcd;
  background-image: -moz-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: -ms-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5bc0de), to(#2f96b4));
  background-image: -webkit-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: -o-linear-gradient(top, #5bc0de, #2f96b4);
  background-image: linear-gradient(top, #5bc0de, #2f96b4);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5bc0de', endColorstr='#2f96b4', GradientType=0);
  border-color: #2f96b4 #2f96b4 #1f6377;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.btn-info:hover,
.btn-info:active,
.btn-info.active,
.btn-info.disabled,
.btn-info[disabled] {
  background-color: #2f96b4;
}
.btn-info:active,
.btn-info.active {
  background-color: #24748c \9;
}
button.btn,
input[type="submit"].btn {
  *padding-top: 2px;
  *padding-bottom: 2px;
}
button.btn::-moz-focus-inner,
input[type="submit"].btn::-moz-focus-inner {
  padding: 0;
  border: 0;
}
button.btn.large,
input[type="submit"].btn.large {
  *padding-top: 7px;
  *padding-bottom: 7px;
}
button.btn.small,
input[type="submit"].btn.small {
  *padding-top: 3px;
  *padding-bottom: 3px;
}
.btn-group {
  position: relative;
  *zoom: 1;
  *margin-left: .3em;
}
.btn-group:before,
.btn-group:after {
  display: table;
  content: "";
}
.btn-group:after {
  clear: both;
}
.btn-group:first-child {
  *margin-left: 0;
}
.btn-group + .btn-group {
  margin-left: 5px;
}
.btn-toolbar {
  margin-top: 9px;
  margin-bottom: 9px;
}
.btn-toolbar .btn-group {
  display: inline-block;
  *display: inline;
  /* IE7 inline-block hack */

  *zoom: 1;
}
.btn-group .btn {
  position: relative;
  float: left;
  margin-left: -1px;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.btn-group .btn:first-child {
  margin-left: 0;
  -webkit-border-top-left-radius: 4px;
  -moz-border-radius-topleft: 4px;
  border-top-left-radius: 4px;
  -webkit-border-bottom-left-radius: 4px;
  -moz-border-radius-bottomleft: 4px;
  border-bottom-left-radius: 4px;
}
.btn-group .btn:last-child,
.btn-group .dropdown-toggle {
  -webkit-border-top-right-radius: 4px;
  -moz-border-radius-topright: 4px;
  border-top-right-radius: 4px;
  -webkit-border-bottom-right-radius: 4px;
  -moz-border-radius-bottomright: 4px;
  border-bottom-right-radius: 4px;
}
.btn-group .btn.large:first-child {
  margin-left: 0;
  -webkit-border-top-left-radius: 6px;
  -moz-border-radius-topleft: 6px;
  border-top-left-radius: 6px;
  -webkit-border-bottom-left-radius: 6px;
  -moz-border-radius-bottomleft: 6px;
  border-bottom-left-radius: 6px;
}
.btn-group .btn.large:last-child,
.btn-group .large.dropdown-toggle {
  -webkit-border-top-right-radius: 6px;
  -moz-border-radius-topright: 6px;
  border-top-right-radius: 6px;
  -webkit-border-bottom-right-radius: 6px;
  -moz-border-radius-bottomright: 6px;
  border-bottom-right-radius: 6px;
}
.btn-group .btn:hover,
.btn-group .btn:focus,
.btn-group .btn:active,
.btn-group .btn.active {
  z-index: 2;
}
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0;
}
.btn-group .dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px;
  -webkit-box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.125), inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.125), inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.125), inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  *padding-top: 5px;
  *padding-bottom: 5px;
}
.btn-group.open {
  *z-index: 1000;
}
.btn-group.open .dropdown-menu {
  display: block;
  margin-top: 1px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.btn-group.open .dropdown-toggle {
  background-image: none;
  -webkit-box-shadow: inset 0 1px 6px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 6px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 6px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.btn .caret {
  margin-top: 7px;
  margin-left: 0;
}
.btn:hover .caret,
.open.btn-group .caret {
  opacity: 1;
  filter: alpha(opacity=100);
}
.btn-primary .caret,
.btn-danger .caret,
.btn-info .caret,
.btn-success .caret {
  border-top-color: #ffffff;
  opacity: 0.75;
  filter: alpha(opacity=75);
}
.btn-small .caret {
  margin-top: 4px;
}
.alert {
  padding: 8px 35px 8px 14px;
  margin-bottom: 18px;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  background-color: #fcf8e3;
  border: 1px solid #fbeed5;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.alert,
.alert-heading {
  color: #c09853;
}
.alert .close {
  position: relative;
  top: -2px;
  right: -21px;
  line-height: 18px;
}
.alert-success {
  background-color: #dff0d8;
  border-color: #d6e9c6;
}
.alert-success,
.alert-success .alert-heading {
  color: #468847;
}
.alert-danger,
.alert-error {
  background-color: #f2dede;
  border-color: #eed3d7;
}
.alert-danger,
.alert-error,
.alert-danger .alert-heading,
.alert-error .alert-heading {
  color: #b94a48;
}
.alert-info {
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.alert-info,
.alert-info .alert-heading {
  color: #3a87ad;
}
.alert-block {
  padding-top: 14px;
  padding-bottom: 14px;
}
.alert-block > p,
.alert-block > ul {
  margin-bottom: 0;
}
.alert-block p + p {
  margin-top: 5px;
}
.nav {
  margin-left: 0;
  margin-bottom: 18px;
  list-style: none;
}
.nav > li > a {
  display: block;
}
.nav > li > a:hover {
  text-decoration: none;
  background-color: #eeeeee;
}
.nav-list {
  padding-left: 14px;
  padding-right: 14px;
  margin-bottom: 0;
}
.nav-list > li > a,
.nav-list .nav-header {
  display: block;
  padding: 3px 15px;
  margin-left: -15px;
  margin-right: -15px;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}
.nav-list .nav-header {
  font-size: 11px;
  font-weight: bold;
  line-height: 18px;
  color: #999999;
  text-transform: uppercase;
}
.nav-list > li + .nav-header {
  margin-top: 9px;
}
.nav-list .active > a,
.nav-list .active > a:hover {
  color: #ffffff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
  background-color: #0088cc;
}
.nav-list [class^="icon-"] {
  margin-right: 2px;
}
.nav-tabs,
.nav-pills {
  *zoom: 1;
}
.nav-tabs:before,
.nav-pills:before,
.nav-tabs:after,
.nav-pills:after {
  display: table;
  content: "";
}
.nav-tabs:after,
.nav-pills:after {
  clear: both;
}
.nav-tabs > li,
.nav-pills > li {
  float: left;
}
.nav-tabs > li > a,
.nav-pills > li > a {
  padding-right: 12px;
  padding-left: 12px;
  margin-right: 2px;
  line-height: 14px;
}
.nav-tabs {
  border-bottom: 1px solid #ddd;
}
.nav-tabs > li {
  margin-bottom: -1px;
}
.nav-tabs > li > a {
  padding-top: 9px;
  padding-bottom: 9px;
  border: 1px solid transparent;
  -webkit-border-radius: 4px 4px 0 0;
  -moz-border-radius: 4px 4px 0 0;
  border-radius: 4px 4px 0 0;
}
.nav-tabs > li > a:hover {
  border-color: #eeeeee #eeeeee #dddddd;
}
.nav-tabs > .active > a,
.nav-tabs > .active > a:hover {
  color: #555555;
  background-color: #ffffff;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
  cursor: default;
}
.nav-pills > li > a {
  padding-top: 8px;
  padding-bottom: 8px;
  margin-top: 2px;
  margin-bottom: 2px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.nav-pills .active > a,
.nav-pills .active > a:hover {
  color: #ffffff;
  background-color: #0088cc;
}
.nav-stacked > li {
  float: none;
}
.nav-stacked > li > a {
  margin-right: 0;
}
.nav-tabs.nav-stacked {
  border-bottom: 0;
}
.nav-tabs.nav-stacked > li > a {
  border: 1px solid #ddd;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.nav-tabs.nav-stacked > li:first-child > a {
  -webkit-border-radius: 4px 4px 0 0;
  -moz-border-radius: 4px 4px 0 0;
  border-radius: 4px 4px 0 0;
}
.nav-tabs.nav-stacked > li:last-child > a {
  -webkit-border-radius: 0 0 4px 4px;
  -moz-border-radius: 0 0 4px 4px;
  border-radius: 0 0 4px 4px;
}
.nav-tabs.nav-stacked > li > a:hover {
  border-color: #ddd;
  z-index: 2;
}
.nav-pills.nav-stacked > li > a {
  margin-bottom: 3px;
}
.nav-pills.nav-stacked > li:last-child > a {
  margin-bottom: 1px;
}
.nav-tabs .dropdown-menu,
.nav-pills .dropdown-menu {
  margin-top: 1px;
  border-width: 1px;
}
.nav-pills .dropdown-menu {
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.nav-tabs .dropdown-toggle .caret,
.nav-pills .dropdown-toggle .caret {
  border-top-color: #0088cc;
  margin-top: 6px;
}
.nav-tabs .dropdown-toggle:hover .caret,
.nav-pills .dropdown-toggle:hover .caret {
  border-top-color: #005580;
}
.nav-tabs .active .dropdown-toggle .caret,
.nav-pills .active .dropdown-toggle .caret {
  border-top-color: #333333;
}
.nav > .dropdown.active > a:hover {
  color: #000000;
  cursor: pointer;
}
.nav-tabs .open .dropdown-toggle,
.nav-pills .open .dropdown-toggle,
.nav > .open.active > a:hover {
  color: #ffffff;
  background-color: #999999;
  border-color: #999999;
}
.nav .open .caret,
.nav .open.active .caret,
.nav .open a:hover .caret {
  border-top-color: #ffffff;
  opacity: 1;
  filter: alpha(opacity=100);
}
.tabs-stacked .open > a:hover {
  border-color: #999999;
}
.tabbable {
  *zoom: 1;
}
.tabbable:before,
.tabbable:after {
  display: table;
  content: "";
}
.tabbable:after {
  clear: both;
}
.tabs-below .nav-tabs,
.tabs-right .nav-tabs,
.tabs-left .nav-tabs {
  border-bottom: 0;
}
.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none;
}
.tab-content > .active,
.pill-content > .active {
  display: block;
}
.tabs-below .nav-tabs {
  border-top: 1px solid #ddd;
}
.tabs-below .nav-tabs > li {
  margin-top: -1px;
  margin-bottom: 0;
}
.tabs-below .nav-tabs > li > a {
  -webkit-border-radius: 0 0 4px 4px;
  -moz-border-radius: 0 0 4px 4px;
  border-radius: 0 0 4px 4px;
}
.tabs-below .nav-tabs > li > a:hover {
  border-bottom-color: transparent;
  border-top-color: #ddd;
}
.tabs-below .nav-tabs .active > a,
.tabs-below .nav-tabs .active > a:hover {
  border-color: transparent #ddd #ddd #ddd;
}
.tabs-left .nav-tabs > li,
.tabs-right .nav-tabs > li {
  float: none;
}
.tabs-left .nav-tabs > li > a,
.tabs-right .nav-tabs > li > a {
  min-width: 74px;
  margin-right: 0;
  margin-bottom: 3px;
}
.tabs-left .nav-tabs {
  float: left;
  margin-right: 19px;
  border-right: 1px solid #ddd;
}
.tabs-left .nav-tabs > li > a {
  margin-right: -1px;
  -webkit-border-radius: 4px 0 0 4px;
  -moz-border-radius: 4px 0 0 4px;
  border-radius: 4px 0 0 4px;
}
.tabs-left .nav-tabs > li > a:hover {
  border-color: #eeeeee #dddddd #eeeeee #eeeeee;
}
.tabs-left .nav-tabs .active > a,
.tabs-left .nav-tabs .active > a:hover {
  border-color: #ddd transparent #ddd #ddd;
  *border-right-color: #ffffff;
}
.tabs-right .nav-tabs {
  float: right;
  margin-left: 19px;
  border-left: 1px solid #ddd;
}
.tabs-right .nav-tabs > li > a {
  margin-left: -1px;
  -webkit-border-radius: 0 4px 4px 0;
  -moz-border-radius: 0 4px 4px 0;
  border-radius: 0 4px 4px 0;
}
.tabs-right .nav-tabs > li > a:hover {
  border-color: #eeeeee #eeeeee #eeeeee #dddddd;
}
.tabs-right .nav-tabs .active > a,
.tabs-right .nav-tabs .active > a:hover {
  border-color: #ddd #ddd #ddd transparent;
  *border-left-color: #ffffff;
}
.navbar {
  overflow: visible;
  margin-bottom: 18px;
}
.navbar-inner {
  padding-left: 20px;
  padding-right: 20px;
  background-color: #2c2c2c;
  background-image: -moz-linear-gradient(top, #333333, #222222);
  background-image: -ms-linear-gradient(top, #333333, #222222);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#333333), to(#222222));
  background-image: -webkit-linear-gradient(top, #333333, #222222);
  background-image: -o-linear-gradient(top, #333333, #222222);
  background-image: linear-gradient(top, #333333, #222222);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#333333', endColorstr='#222222', GradientType=0);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
  -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.25), inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}
.btn-navbar {
  display: none;
  float: right;
  padding: 7px 10px;
  margin-left: 5px;
  margin-right: 5px;
  background-color: #2c2c2c;
  background-image: -moz-linear-gradient(top, #333333, #222222);
  background-image: -ms-linear-gradient(top, #333333, #222222);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#333333), to(#222222));
  background-image: -webkit-linear-gradient(top, #333333, #222222);
  background-image: -o-linear-gradient(top, #333333, #222222);
  background-image: linear-gradient(top, #333333, #222222);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#333333', endColorstr='#222222', GradientType=0);
  border-color: #222222 #222222 #000000;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.075);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.075);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.075);
}
.btn-navbar:hover,
.btn-navbar:active,
.btn-navbar.active,
.btn-navbar.disabled,
.btn-navbar[disabled] {
  background-color: #222222;
}
.btn-navbar:active,
.btn-navbar.active {
  background-color: #080808 \9;
}
.btn-navbar .icon-bar {
  display: block;
  width: 18px;
  height: 2px;
  background-color: #f5f5f5;
  -webkit-border-radius: 1px;
  -moz-border-radius: 1px;
  border-radius: 1px;
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
  -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
}
.btn-navbar .icon-bar + .icon-bar {
  margin-top: 3px;
}
.nav-collapse.collapse {
  height: auto;
}
.navbar .brand:hover {
  text-decoration: none;
}
.navbar .brand {
  float: left;
  display: block;
  padding: 8px 20px 12px;
  margin-left: -20px;
  font-size: 20px;
  font-weight: 200;
  line-height: 1;
  color: #ffffff;
}
.navbar .navbar-text {
  margin-bottom: 0;
  line-height: 40px;
  color: #999999;
}
.navbar .navbar-text a:hover {
  color: #ffffff;
  background-color: transparent;
}
.navbar .btn,
.navbar .btn-group {
  margin-top: 5px;
}
.navbar .btn-group .btn {
  margin-top: 0;
}
.navbar-form {
  margin-bottom: 0;
  *zoom: 1;
}
.navbar-form:before,
.navbar-form:after {
  display: table;
  content: "";
}
.navbar-form:after {
  clear: both;
}
.navbar-form input,
.navbar-form select {
  display: inline-block;
  margin-top: 5px;
  margin-bottom: 0;
}
.navbar-form .radio,
.navbar-form .checkbox {
  margin-top: 5px;
}
.navbar-form input[type="image"],
.navbar-form input[type="checkbox"],
.navbar-form input[type="radio"] {
  margin-top: 3px;
}
.navbar-search {
  position: relative;
  float: left;
  margin-top: 6px;
  margin-bottom: 0;
}
.navbar-search .search-query {
  padding: 4px 9px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 13px;
  font-weight: normal;
  line-height: 1;
  color: #ffffff;
  color: rgba(255, 255, 255, 0.75);
  background: #666;
  background: rgba(255, 255, 255, 0.3);
  border: 1px solid #111;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1), 0 1px 0px rgba(255, 255, 255, 0.15);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1), 0 1px 0px rgba(255, 255, 255, 0.15);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1), 0 1px 0px rgba(255, 255, 255, 0.15);
  -webkit-transition: none;
  -moz-transition: none;
  -ms-transition: none;
  -o-transition: none;
  transition: none;
}
.navbar-search .search-query :-moz-placeholder {
  color: #eeeeee;
}
.navbar-search .search-query ::-webkit-input-placeholder {
  color: #eeeeee;
}
.navbar-search .search-query:hover {
  color: #ffffff;
  background-color: #999999;
  background-color: rgba(255, 255, 255, 0.5);
}
.navbar-search .search-query:focus,
.navbar-search .search-query.focused {
  padding: 5px 10px;
  color: #333333;
  text-shadow: 0 1px 0 #ffffff;
  background-color: #ffffff;
  border: 0;
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  -moz-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
  outline: 0;
}
.navbar-fixed-top {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
  z-index: 1030;
}
.navbar-fixed-top .navbar-inner {
  padding-left: 0;
  padding-right: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.navbar .nav {
  position: relative;
  left: 0;
  display: block;
  float: left;
  margin: 0 10px 0 0;
}
.navbar .nav.pull-right {
  float: right;
}
.navbar .nav > li {
  display: block;
  float: left;
}
.navbar .nav > li > a {
  float: none;
  padding: 10px 10px 11px;
  line-height: 19px;
  color: #999999;
  text-decoration: none;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
}
.navbar .nav > li > a:hover {
  background-color: transparent;
  color: #ffffff;
  text-decoration: none;
}
.navbar .nav .active > a,
.navbar .nav .active > a:hover {
  color: #ffffff;
  text-decoration: none;
  background-color: #222222;
  background-color: rgba(0, 0, 0, 0.5);
}
.navbar .divider-vertical {
  height: 40px;
  width: 1px;
  margin: 0 9px;
  overflow: hidden;
  background-color: #222222;
  border-right: 1px solid #333333;
}
.navbar .nav.pull-right {
  margin-left: 10px;
  margin-right: 0;
}
.navbar .dropdown-menu {
  margin-top: 1px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.navbar .dropdown-menu:before {
  content: '';
  display: inline-block;
  border-left: 7px solid transparent;
  border-right: 7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -7px;
  left: 9px;
}
.navbar .dropdown-menu:after {
  content: '';
  display: inline-block;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #ffffff;
  position: absolute;
  top: -6px;
  left: 10px;
}
.navbar .nav .dropdown-toggle .caret,
.navbar .nav .open.dropdown .caret {
  border-top-color: #ffffff;
}
.navbar .nav .active .caret {
  opacity: 1;
  filter: alpha(opacity=100);
}
.navbar .nav .open > .dropdown-toggle,
.navbar .nav .active > .dropdown-toggle,
.navbar .nav .open.active > .dropdown-toggle {
  background-color: transparent;
}
.navbar .nav .active > .dropdown-toggle:hover {
  color: #ffffff;
}
.navbar .nav.pull-right .dropdown-menu {
  left: auto;
  right: 0;
}
.navbar .nav.pull-right .dropdown-menu:before {
  left: auto;
  right: 12px;
}
.navbar .nav.pull-right .dropdown-menu:after {
  left: auto;
  right: 13px;
}
.breadcrumb {
  padding: 7px 14px;
  margin: 0 0 18px;
  background-color: #fbfbfb;
  background-image: -moz-linear-gradient(top, #ffffff, #f5f5f5);
  background-image: -ms-linear-gradient(top, #ffffff, #f5f5f5);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#f5f5f5));
  background-image: -webkit-linear-gradient(top, #ffffff, #f5f5f5);
  background-image: -o-linear-gradient(top, #ffffff, #f5f5f5);
  background-image: linear-gradient(top, #ffffff, #f5f5f5);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f5f5f5', GradientType=0);
  border: 1px solid #ddd;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  -webkit-box-shadow: inset 0 1px 0 #ffffff;
  -moz-box-shadow: inset 0 1px 0 #ffffff;
  box-shadow: inset 0 1px 0 #ffffff;
}
.breadcrumb li {
  display: inline;
  text-shadow: 0 1px 0 #ffffff;
}
.breadcrumb .divider {
  padding: 0 5px;
  color: #999999;
}
.breadcrumb .active a {
  color: #333333;
}
.pager {
  margin-left: 0;
  margin-bottom: 18px;
  list-style: none;
  text-align: center;
  *zoom: 1;
}
.pager:before,
.pager:after {
  display: table;
  content: "";
}
.pager:after {
  clear: both;
}
.pager li {
  display: inline;
}
.pager a {
  display: inline-block;
  padding: 5px 14px;
  background-color: #fff;
  border: 1px solid #ddd;
  -webkit-border-radius: 15px;
  -moz-border-radius: 15px;
  border-radius: 15px;
}
.pager a:hover {
  text-decoration: none;
  background-color: #f5f5f5;
}
.pager .next a {
  float: right;
}
.pager .previous a {
  float: left;
}
.modal-open .dropdown-menu {
  z-index: 2050;
}
.modal-open .dropdown.open {
  *z-index: 2050;
}
.modal-open .popover {
  z-index: 2060;
}
.modal-open .tooltip {
  z-index: 2070;
}
.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #000000;
}
.modal-backdrop.fade {
  opacity: 0;
}
.modal-backdrop,
.modal-backdrop.fade.in {
  opacity: 0.8;
  filter: alpha(opacity=80);
}
.modal {
  position: fixed;
  top: 50%;
  left: 50%;
  z-index: 1050;
  max-height: 500px;
  overflow: auto;
  width: 560px;
  margin: -250px 0 0 -280px;
  background-color: #ffffff;
  border: 1px solid #999;
  border: 1px solid rgba(0, 0, 0, 0.3);
  *border: 1px solid #999;
  /* IE6-7 */

  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding-box;
  background-clip: padding-box;
}
.modal.fade {
  -webkit-transition: opacity .3s linear, top .3s ease-out;
  -moz-transition: opacity .3s linear, top .3s ease-out;
  -ms-transition: opacity .3s linear, top .3s ease-out;
  -o-transition: opacity .3s linear, top .3s ease-out;
  transition: opacity .3s linear, top .3s ease-out;
  top: -25%;
}
.modal.fade.in {
  top: 50%;
}
.modal-header {
  padding: 9px 15px;
  border-bottom: 1px solid #eee;
}
.modal-header .close {
  margin-top: 2px;
}
.modal-body {
  padding: 15px;
}
.modal-footer {
  padding: 14px 15px 15px;
  margin-bottom: 0;
  background-color: #f5f5f5;
  border-top: 1px solid #ddd;
  -webkit-border-radius: 0 0 6px 6px;
  -moz-border-radius: 0 0 6px 6px;
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: inset 0 1px 0 #ffffff;
  -moz-box-shadow: inset 0 1px 0 #ffffff;
  box-shadow: inset 0 1px 0 #ffffff;
  *zoom: 1;
}
.modal-footer:before,
.modal-footer:after {
  display: table;
  content: "";
}
.modal-footer:after {
  clear: both;
}
.modal-footer .btn {
  float: right;
  margin-left: 5px;
  margin-bottom: 0;
}
.label {
  padding: 1px 3px 2px;
  font-size: 9.75px;
  font-weight: bold;
  color: #ffffff;
  text-transform: uppercase;
  background-color: #999999;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.label-important {
  background-color: #b94a48;
}
.label-warning {
  background-color: #f89406;
}
.label-success {
  background-color: #468847;
}
.label-info {
  background-color: #3a87ad;
}
.carousel {
  position: relative;
  margin-bottom: 18px;
  line-height: 1;
}
.carousel-inner {
  overflow: hidden;
  width: 100%;
  position: relative;
}
.carousel .item {
  display: none;
  position: relative;
  -webkit-transition: 0.6s ease-in-out left;
  -moz-transition: 0.6s ease-in-out left;
  -ms-transition: 0.6s ease-in-out left;
  -o-transition: 0.6s ease-in-out left;
  transition: 0.6s ease-in-out left;
}
.carousel .item > img {
  display: block;
  line-height: 1;
}
.carousel .active,
.carousel .next,
.carousel .prev {
  display: block;
}
.carousel .active {
  left: 0;
}
.carousel .next,
.carousel .prev {
  position: absolute;
  top: 0;
  width: 100%;
}
.carousel .next {
  left: 100%;
}
.carousel .prev {
  left: -100%;
}
.carousel .next.left,
.carousel .prev.right {
  left: 0;
}
.carousel .active.left {
  left: -100%;
}
.carousel .active.right {
  left: 100%;
}
.carousel-control {
  position: absolute;
  top: 40%;
  left: 15px;
  width: 40px;
  height: 40px;
  margin-top: -20px;
  font-size: 60px;
  font-weight: 100;
  line-height: 30px;
  color: #ffffff;
  text-align: center;
  background: #222222;
  border: 3px solid #ffffff;
  -webkit-border-radius: 23px;
  -moz-border-radius: 23px;
  border-radius: 23px;
  opacity: 0.5;
  filter: alpha(opacity=50);
}
.carousel-control.right {
  left: auto;
  right: 15px;
}
.carousel-control:hover {
  color: #ffffff;
  text-decoration: none;
  opacity: 0.9;
  filter: alpha(opacity=90);
}
.carousel-caption {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  padding: 10px 15px 5px;
  background: #333333;
  background: rgba(0, 0, 0, 0.75);
}
.carousel-caption h4,
.carousel-caption p {
  color: #ffffff;
}
.hero-unit {
  padding: 60px;
  margin-bottom: 30px;
  background-color: #f5f5f5;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.hero-unit h1 {
  margin-bottom: 0;
  font-size: 60px;
  line-height: 1;
  letter-spacing: -1px;
}
.hero-unit p {
  font-size: 18px;
  font-weight: 200;
  line-height: 27px;
}
body {
  background-color: #eeeeee;
}
.container-fluid {
  padding: 0px;
  margin: 0px auto;
  max-width: 960px;
}
.page {
  background: #ffffff;
  -webkit-border-radius: 0 0 6px 6px;
  -moz-border-radius: 0 0 6px 6px;
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
  -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.15);
}
.page_inner {
  padding: 20px;
  *zoom: 1;
}
.page_inner:before,
.page_inner:after {
  display: table;
  content: "";
}
.page_inner:after {
  clear: both;
}
.navbar.primary {
  margin-bottom: 0px;
  margin-top: 26px;
}
.navbar.primary .brand.hidden {
  display: none;
}
.navbar.primary .form-search .btn {
  margin-top: 0px;
}
.navbar.accounts {
  margin-bottom: 52px;
}
.navbar.accounts .navbar-inner {
  -webkit-border-radius: inherit;
  -moz-border-radius: inherit;
  border-radius: inherit;
}
.well {
  *zoom: 1;
}
.well:before,
.well:after {
  display: table;
  content: "";
}
.well:after {
  clear: both;
}
.well-success {
  background-color: #dff0d8;
  border-color: #d6e9c6;
}
.well-danger {
  background-color: #f2dede;
  border-color: #eed3d7;
}
.well-info {
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.well-blank {
  background-color: #ffffff;
  border-color: rgba(0, 0, 0, 0.1);
}
.pull-clear {
  clear: both;
}
form {
  *zoom: 1;
}
form:before,
form:after {
  display: table;
  content: "";
}
form:after {
  clear: both;
}
.form-actions {
  *zoom: 1;
}
.form-actions:before,
.form-actions:after {
  display: table;
  content: "";
}
.form-actions:after {
  clear: both;
}
.errorlist {
  margin: 0;
  padding: 0 0 10px 0;
  color: #B94A48;
}
.errorlist li {
  padding: 0 0 5px 0;
  list-style: none;
}
.control-label.required:after {
  content: "*";
  padding: 0 0 0 3px;
  color: #FF0000;
}
.header {
  text-shadow: 0 1px 0 white;
  position: relative;
  z-index: 2;
}
.header h1 {
  line-height: inherit;
}
.page-header,
.sub-header {
  background: #f9f9f9;
  padding: 20px;
  margin-top: 0px;
  margin-bottom: 18px;
  border-bottom: 1px solid #e0e0e0;
}
.page-header {
  margin-bottom: 0px;
}
.sub-header {
  background: none;
  padding: 0px 0px 10px;
}
.page-header.action {
  *zoom: 1;
  margin-bottom: 0px;
}
.page-header.action:before,
.page-header.action:after {
  display: table;
  content: "";
}
.page-header.action:after {
  clear: both;
}
.page-header.action h1,
.page-header.action h2 {
  float: left;
  margin-bottom: 0px;
}
.cart {
  margin: 0px;
  *zoom: 1;
}
.cart:before,
.cart:after {
  display: table;
  content: "";
}
.cart:after {
  clear: both;
}
.cart .cart_summary strong {
  padding: 4px 10px 4px;
  display: block;
}
.cart .cart_summary strong span {
  font-weight: normal;
}
.cart li {
  display: block;
  float: right;
}
.cart li .btn-group .dropdown-menu {
  left: auto;
  right: 0px;
  width: 300px;
  padding-bottom: 0px;
  max-width: none;
}
.cart li .btn-group .dropdown-menu li {
  width: 100%;
  float: none;
  display: block;
}
.cart li .btn-group .dropdown-menu .basket_item {
  margin: 0px;
}
.cart li .btn-group .dropdown-menu .basket_item li {
  width: auto;
  border-top: 1px solid #eeeeee;
  padding: 10px 15px;
}
.cart li .btn-group .dropdown-menu .basket_item li:first-child {
  border-top: none;
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions {
  -webkit-border-radius: 0 0px 6px 6px;
  -moz-border-radius: 0 0px 6px 6px;
  border-radius: 0 0px 6px 6px;
  margin: 0px;
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions p {
  *zoom: 1;
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions p:before,
.cart li .btn-group .dropdown-menu .basket_item .form-actions p:after {
  display: table;
  content: "";
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions p:after {
  clear: both;
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions p .btn {
  float: right;
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions h4 {
  text-align: right;
  margin-bottom: 13px;
}
.cart li .btn-group .dropdown-menu .basket_item .form-actions h4 small {
  display: block;
}
.cart li .btn-group .dropdown-menu .basket_item a {
  color: #0088cc;
  font-weight: inherit;
  white-space: normal;
}
.cart li .btn-group .dropdown-menu .basket_item a.btn {
  color: #fff;
}
.cart li .btn-group .dropdown-menu .basket_item a.primary {
  background-color: #0286d5;
  background-image: -moz-linear-gradient(top, #049cdb, #0064cd);
  background-image: -ms-linear-gradient(top, #049cdb, #0064cd);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#049cdb), to(#0064cd));
  background-image: -webkit-linear-gradient(top, #049cdb, #0064cd);
  background-image: -o-linear-gradient(top, #049cdb, #0064cd);
  background-image: linear-gradient(top, #049cdb, #0064cd);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#049cdb', endColorstr='#0064cd', GradientType=0);
  border-color: #0064cd #0064cd #003f81;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
}
.cart li .btn-group .dropdown-menu .basket_item a.primary:hover {
  background-position: 0 -15px;
}
.cart li .btn-group .dropdown-menu .basket_item h4 {
  font-size: 14px;
}
.cart li .btn-group .dropdown-menu .basket_item h4 a {
  padding: 0px;
}
.footer_links {
  padding: 0px;
  margin: 0px;
  *zoom: 1;
  *zoom: 1;
  border-bottom: 1px solid #cccccc;
  padding: 13px;
  margin-bottom: 18px;
}
.footer_links:before,
.footer_links:after {
  display: table;
  content: "";
}
.footer_links:after {
  clear: both;
}
.footer_links > li {
  list-style: none;
}
.footer_links li {
  float: left;
}
.footer_links li li {
  float: none;
}
.footer_links:before,
.footer_links:after {
  display: table;
  content: "";
}
.footer_links:after {
  clear: both;
}
.footer_links li {
  margin-left: 10px;
  padding-left: 10px;
  border-left: 1px solid #cccccc;
}
.footer_links li:first-child,
.footer_links li:last-child {
  margin-left: 0px;
  padding-left: 0px;
  border-left: none;
}
.footer_links .top_page {
  float: right;
}
#browse .dropdown-menu > li:hover .sub-nav,
#browse .dropdown-menu > li > a:hover .sub-nav,
#browse .dropdown-menu > li:hover {
  visibility: visible;
  background-color: #efefef;
  border-right-color: #efefef;
  -webkit-box-shadow: 5px 5px 7px -1px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 5px 5px 7px -1px rgba(0, 0, 0, 0.2);
  box-shadow: 5px 5px 7px -1px rgba(0, 0, 0, 0.2);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding;
  background-clip: padding-box;
}
.navbar #menu2.dropdown.open > a {
  background-position: 0 -15px;
}
.navbar #browse > a {
  display: inline-block;
  padding: 4px 10px 4px;
  font-size: 13px;
  line-height: 18px;
  color: #333333;
  text-align: center;
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
  background-color: #fafafa;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), color-stop(25%, #ffffff), to(#e6e6e6));
  background-image: -webkit-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-image: -moz-linear-gradient(top, #ffffff, #ffffff 25%, #e6e6e6);
  background-image: -ms-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-image: -o-linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-image: linear-gradient(#ffffff, #ffffff 25%, #e6e6e6);
  background-repeat: no-repeat;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
  border: 1px solid #ccc;
  border-bottom-color: #bbb;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
  cursor: pointer;
  *margin-left: .3em;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  color: #ffffff;
  background-color: #006dcc;
  background-image: -moz-linear-gradient(top, #0088cc, #0044cc);
  background-image: -ms-linear-gradient(top, #0088cc, #0044cc);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0088cc), to(#0044cc));
  background-image: -webkit-linear-gradient(top, #0088cc, #0044cc);
  background-image: -o-linear-gradient(top, #0088cc, #0044cc);
  background-image: linear-gradient(top, #0088cc, #0044cc);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0088cc', endColorstr='#0044cc', GradientType=0);
  border-color: #0044cc #0044cc #002a80;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  margin: 5px 10px 5px 0px;
  padding: 5px 10px 6px;
}
.navbar #browse > a:first-child {
  *margin-left: 0;
}
.navbar #browse > a:hover,
.navbar #browse > a:active,
.navbar #browse > a.active,
.navbar #browse > a.disabled,
.navbar #browse > a[disabled] {
  background-color: #0044cc;
}
.navbar #browse > a:active,
.navbar #browse > a.active {
  background-color: #003399 \9;
}
.navbar #browse > a .caret {
  border-top-color: #ffffff;
  opacity: 0.75;
  filter: alpha(opacity=75);
}
.navbar #browse > a:hover {
  background-position: 0 -15px;
}
.navbar #browse a {
  border: none;
  display: block;
  clear: none;
  position: relative;
  line-height: 18px;
}
.navbar #browse .dropdown-menu {
  width: 212px;
  padding: 0px;
  border: none;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  border-radius: 0px;
  margin-top: 0px;
}
.navbar #browse .dropdown-menu:before,
.navbar #browse .dropdown-menu:after {
  content: none;
}
.navbar #browse .nav.sub-nav {
  visibility: hidden;
  position: absolute;
  left: 100%;
  top: 0px;
}
.navbar #browse .nav.sub-nav > li {
  float: none;
}
.navbar #browse .nav.sub-nav > li > a {
  padding: 9px 12px;
}
.navbar #browse .nav-tabs.nav-stacked > li span {
  position: absolute;
  right: 5%;
}
.navbar #browse .nav-tabs.nav-stacked > li .sub-nav a:hover {
  background-color: #08C;
}
.navbar #browse .nav-tabs.nav-stacked > li .sub-nav > li {
  border: 1px solid #efefef;
  border-top-width: 0px;
}
.navbar #browse .nav-tabs.nav-stacked > li:last-child > a,
.navbar #browse .nav-tabs.nav-stacked > li:first-child > a {
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  border-radius: 0px;
}
#browse .nav-tabs > li {
  border: 1px solid #ddd;
  border-top-width: 0px;
  margin-bottom: 0px;
  position: relative;
}
/* Account Navbar */
.navbar.accounts .nav div {
  padding: 10px 10px 11px;
  line-height: 19px;
  display: block;
  color: #999999;
}
/* Account Styles */
.account_settings,
.new_address {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #eee;
  border: 1px solid rgba(0, 0, 0, 0.05);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  *zoom: 1;
}
.account_settings blockquote,
.new_address blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.account_settings:before,
.new_address:before,
.account_settings:after,
.new_address:after {
  display: table;
  content: "";
}
.account_settings:after,
.new_address:after {
  clear: both;
}
.login_form form,
.register_form form {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #eee;
  border: 1px solid rgba(0, 0, 0, 0.05);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  *zoom: 1;
}
.login_form form blockquote,
.register_form form blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.login_form form:before,
.register_form form:before,
.login_form form:after,
.register_form form:after {
  display: table;
  content: "";
}
.login_form form:after,
.register_form form:after {
  clear: both;
}
.login_form form h2,
.register_form form h2 {
  margin-bottom: 18px;
  font-size: 18px;
}
.tabbable.dashboard .nav {
  margin-bottom: 0px;
}
.tabbable.dashboard .nav-tabs > li > a {
  background: #f5f5f5;
  background-color: #e0e0e0;
  background-image: -moz-linear-gradient(top, #cccccc, #ffffff);
  background-image: -ms-linear-gradient(top, #cccccc, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#cccccc), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #cccccc, #ffffff);
  background-image: -o-linear-gradient(top, #cccccc, #ffffff);
  background-image: linear-gradient(top, #cccccc, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#cccccc', endColorstr='#ffffff', GradientType=0);
  border: 1px solid #DDD;
  margin: 6px 10px 0 0;
  color: #555555;
  font-weight: bold;
  text-shadow: 1px 1px 0 #fff;
}
.tabbable.dashboard .nav-tabs > li.active a,
.tabbable.dashboard .nav-tabs > li > a:hover {
  background: #f5f5f5;
  border-bottom-color: transparent;
  background-color: #f5f5f5;
  background-image: -moz-linear-gradient(top, #eeeeee, #ffffff);
  background-image: -ms-linear-gradient(top, #eeeeee, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #eeeeee, #ffffff);
  background-image: -o-linear-gradient(top, #eeeeee, #ffffff);
  background-image: linear-gradient(top, #eeeeee, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#ffffff', GradientType=0);
  border-bottom: 1px solid #fff;
  outline: none;
  font-weight: bold;
  color: #0088CC;
  margin-top: 0;
  height: 20px;
}
.tabbable.dashboard .tab-content {
  padding: 18px;
  border: 1px solid #e1e1e1;
  border-top-width: 0px;
  background: #fff;
  -webkit-border-bottom-right-radius: 5px;
  -webkit-border-bottom-left-radius: 5px;
  -moz-border-radius-bottomright: 5px;
  -moz-border-radius-bottomleft: 5px;
  border-bottom-right-radius: 5px;
  border-bottom-left-radius: 5px;
}
.basket_summary,
.later_summary {
  padding-left: 0px;
}
.basket_summary .actions,
.later_summary .actions {
  margin-left: 0px;
}
.basket_summary .checkout-quantity input,
.later_summary .checkout-quantity input {
  width: 10%;
  margin-right: 2px;
  margin-bottom: 0px;
}
.basket_summary .basket-products,
.later_summary .basket-products {
  border-bottom: 1px solid #E0E0E0;
  padding: 0 0 10px;
  margin-bottom: 18px;
}
.basket-title {
  clear: both;
  border-bottom: 1px solid #e5e5e5;
  padding: 10px;
}
.basket-items {
  border-bottom: 1px solid #e5e5e5;
  padding: 10px;
}
.basket-items [class*="span"] .image_container {
  height: 50px;
  width: 70px;
  float: left;
  margin-right: 15px;
}
.basket-items [class*="span"] img {
  max-height: 50px;
}
.basket-items:nth-child(even) {
  background: #f8f8f8;
}
.basket-items .price {
  font-size: 15px;
  color: #46a546;
  font-weight: bold;
  text-align: center;
}
/*.basket_summary .row-fluid input {
    width: 20%;
}*/
.order_summary {
  margin: 0px 0px;
  padding: 0px;
  *zoom: 1;
  padding-top: 0px;
}
.order_summary:before,
.order_summary:after {
  display: table;
  content: "";
}
.order_summary:after {
  clear: both;
}
.order_summary li {
  display: block;
}
.order_summary li a {
  display: block;
  padding: 4px 0px;
  width: 100%;
  line-height: 18px;
}
.order_summary ul {
  margin: 0px;
}
.order_summary li {
  border-bottom: 1px solid #999999;
  padding: 2px 0px;
  margin-bottom: 9px;
}
.order_summary li h6 {
  line-height: 18px;
  margin-bottom: 9px;
  color: #333333;
  font-size: 11px;
}
.order_summary li li {
  border-bottom: none;
  margin: 0px 0px;
}
.order_summary li li span {
  color: #555555;
}
.order_summary li {
  border-color: #333333;
  border-style: dashed;
  *zoom: 1;
}
.order_summary li:before,
.order_summary li:after {
  display: table;
  content: "";
}
.order_summary li:after {
  clear: both;
}
.order_summary li strong {
  float: left;
  color: #333333;
}
.order_summary li span {
  float: right;
}
.order_summary li .total {
  background-color: transparent;
}
.shipping_address h2 {
  margin-bottom: 18px;
}
.choose-block {
  margin-top: 10px;
}
.choose-block ul {
  margin: 0px;
  padding: 0px;
  *zoom: 1;
}
.choose-block ul li {
  padding: 0px;
  list-style: none;
}
.choose-block ul:before,
.choose-block ul:after {
  display: table;
  content: "";
}
.choose-block ul:after {
  clear: both;
}
.choose-block ul li {
  width: 33.33333333333333%;
  float: left;
}
.choose-block .well {
  position: relative;
}
.choose-block .well form {
  position: relative;
  padding-bottom: 35px;
  margin-bottom: 0;
}
.choose-block .well form .ship-address {
  bottom: 0;
  position: absolute;
}
.choose-block .well .remove-item {
  position: absolute;
  bottom: 10px;
  right: 19px;
  margin-bottom: 0;
}
.choose-block .well .remove-item input {
  margin-bottom: 0;
}
.choose-block .alert-actions {
  *zoom: 1;
}
.choose-block .alert-actions:before,
.choose-block .alert-actions:after {
  display: table;
  content: "";
}
.choose-block .alert-actions:after {
  clear: both;
}
.choose-block .alert-actions form,
.choose-block .alert-actions a {
  float: left;
  margin: 0px 5px;
}
.choose-block .alert-actions form input {
  width: auto;
}
.total {
  background-color: #FDF5D9!important;
}
.checkoutNav ul li {
  background: none repeat scroll 0 0 #eeeeee;
  color: #FFFFFF;
  float: left;
  height: 24px;
  line-height: 24px;
  margin: 0;
  padding: 1px 0 4px;
  position: relative;
  text-decoration: none;
}
.checkoutNav ul li h3 {
  text-align: center;
  font-size: 11px;
  color: #999999;
  margin-left: 12px;
}
.checkoutNav ul li:after {
  border-color: transparent transparent transparent #eeeeee;
  border-style: solid;
  border-width: 14px 0 15px 15px;
  content: "";
  float: left;
  height: 0;
  position: absolute;
  right: -15px;
  top: 0;
  width: 0;
}
.checkoutNav ul li.active:after {
  border-color: transparent transparent transparent #0088CC;
}
.checkoutNav ul li.active {
  background-color: #0088CC;
}
.checkoutNav ul li:before {
  border-color: transparent transparent transparent #fff;
  border-style: solid;
  border-width: 15px 0 15px 15px;
  content: "";
  float: left;
  height: 0;
  left: 0;
  position: absolute;
  top: 0;
  width: 0;
}
.checkoutNav ul li.active h3 {
  color: #fff;
  text-align: center;
  font-size: 12px;
}
/*  Procduct columns*/
.five li {
  width: 20%;
}
.four li {
  width: 25%;
}
.three li {
  width: 33.33333333333333%;
}
.two li {
  width: 50%;
}
.one li {
  width: 100%;
}
.five li li,
.four li li,
.three li li,
.two li li,
.one li li {
  width: auto;
}
.products {
  padding: 0px;
  margin: 0px;
  *zoom: 1;
}
.products:before,
.products:after {
  display: table;
  content: "";
}
.products:after {
  clear: both;
}
.products > li {
  list-style: none;
}
.products li {
  float: left;
}
.products li li {
  float: none;
}
.product_pod {
  padding: 8%;
  position: relative;
  height: 375px;
  overflow: hidden;
  text-align: center;
  *zoom: 1;
}
.product_pod:before,
.product_pod:after {
  display: table;
  content: "";
}
.product_pod:after {
  clear: both;
}
.product_pod p {
  margin-bottom: 0;
}
.product_pod h3 {
  font-size: 1em;
  margin-bottom: 0;
  line-height: 18px;
}
.product_pod h3 a {
  line-height: 18px;
}
.product_pod h4 {
  *zoom: 1;
  margin-bottom: 18px;
  margin-top: 9px;
  line-height: 18px;
  font-size: 16px;
  /*span {
          float:right;
        }
        del {
          float:left;
          font-size:0.611em;
          font-weight:normal;
          color:lighten(@grayDark, 40%);
        }*/

}
.product_pod h4:before,
.product_pod h4:after {
  display: table;
  content: "";
}
.product_pod h4:after {
  clear: both;
}
.product_pod .avaliability {
  margin-bottom: 9px;
  text-align: center;
}
.product_pod button {
  width: 100%;
}
.product_pod .product_price {
  position: absolute;
  bottom: 8%;
  left: 8%;
  width: 84%;
}
.product_pod .product_price form {
  margin-bottom: 0px;
}
.product_pod .product_price form input#id_quantity,
.product_pod .product_price form #id_product_id {
  width: 90%;
}
.product_pod .product_price .btn {
  padding-left: 0px;
  padding-right: 0px;
  width: 100%;
}
/* carosel product list mods */
.es-carousel .product_pod {
  height: 250px;
}
.es-carousel .product_pod .product_price {
  bottom: 0px;
}
/* Product list image container */
.image_container {
  width: 100%;
  height: 125px;
  overflow: hidden;
  text-align: center;
  margin-bottom: 9px;
  position: relative;
}
.image_container img {
  /*    height:100%;*/

  max-height: 125px;
  width: auto;
  margin: 0px auto;
}
/* For vertical product lists ADD class vertical */
.products.vertical li {
  margin-bottom: 18px;
}
.products.vertical li .product_pod {
  padding: 0px;
}
.products.vertical li .product_pod .image_container {
  width: 25%;
  float: left;
  margin-right: 15px;
  margin-bottom: 0px;
}
.products.vertical li .product_pod .avaliability {
  text-align: left;
}
.products.vertical li .product_pod .product_price {
  position: static;
  width: auto;
}
.products.vertical li .product_pod .product_price h4 {
  display: inline;
}
.products.vertical li .product_pod .product_price h4 span,
.products.vertical li .product_pod .product_price h4 del {
  float: none;
}
.products.vertical li .product_pod .product_price .btn {
  width: auto;
  display: block;
  padding: 5px 14px 6px;
  margin-top: 5px;
}
.products.three.vertical li,
.products.four.vertical li,
.products.five.vertical li {
  width: auto;
  float: none;
  border-bottom: 1px solid #eeeeee;
  padding-bottom: 18px;
}
.products.three.vertical li .product_pod,
.products.four.vertical li .product_pod,
.products.five.vertical li .product_pod {
  height: auto;
}
.products.two.vertical li .product_pod {
  height: auto;
}
.products.two.vertical li:nth-child(2n-1) {
  clear: both;
}
.avaliability {
  /*  text-align:center;*/

}
.avaliability.outofstock {
  color: #9d261d;
}
.avaliability.instock {
  color: #46a546;
}
/* Product View image container */
.images img {
  width: 100%;
  height: auto;
}
/* Product Page */
.price_color {
  display: block;
  color: #46a546;
}
.basic label {
  width: auto;
}
.basic .input {
  margin: 0px;
}
.basic .input input {
  margin: 0px 10px;
}
.promo_related {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #eee;
  border: 1px solid rgba(0, 0, 0, 0.05);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  *zoom: 1;
  height: 250px;
}
.promo_related blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.promo_related:before,
.promo_related:after {
  display: table;
  content: "";
}
.promo_related:after {
  clear: both;
}
/* review styles */
.review {
  border-bottom: 1px solid #999999;
  *zoom: 1;
}
.review:before,
.review:after {
  display: table;
  content: "";
}
.review:after {
  clear: both;
}
.review h3 {
  margin-top: 10px;
  margin-bottom: 10px;
  font-size: 16px;
  overflow: hidden;
  text-overflow: ellipsis;
}
.review h3 small {
  font-size: 12px;
}
.review h4 {
  border-top: 1px solid #eeeeee;
  border-bottom: 1px solid #999999;
  font-size: 14px;
}
.review_content div {
  padding: 15px;
  padding-left: 0px;
  border-right: dotted 1px #999999;
}
.review_votes div {
  padding: 15px;
  padding-left: 0px;
  padding-bottom: 0px;
}
.review_votes .vote_agree {
  float: left;
  margin-right: 10px;
}
.review_votes form {
  padding-bottom: 10px;
  margin-bottom: 0px;
}
.review_votes form input {
  /*      width:70px;*/

}
.review_add,
.review_all,
.review_read,
.side_categories {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #eee;
  border: 1px solid rgba(0, 0, 0, 0.05);
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  *zoom: 1;
}
.review_add blockquote,
.review_all blockquote,
.review_read blockquote,
.side_categories blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.review_add:before,
.review_all:before,
.review_read:before,
.side_categories:before,
.review_add:after,
.review_all:after,
.review_read:after,
.side_categories:after {
  display: table;
  content: "";
}
.review_add:after,
.review_all:after,
.review_read:after,
.side_categories:after {
  clear: both;
}
/* This is needed for ie7 */
#main_slider,
#secondary_slider {
  height: 320px;
}
/* Elastislide Style */
.es-carousel-wrapper {
  /*  background: #efefef;*/

  padding: 1px 20px;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  border-radius: 4px;
  position: relative;
  margin-bottom: 30px;
  overflow: hidden;
  border: 1px solid #ddd;
}
.es-carousel {
  overflow: hidden;
  border-right: 1px solid #ddd;
  border-left: 1px solid #ddd;
}
.es-carousel ul {
  display: none;
}
.es-carousel ul li {
  height: 100%;
  float: left;
  display: block;
}
.es-carousel ul li a {
  /*display:block;
	 border-style:solid;
	 border-color:#999;
	 opacity:0.8;*/

  -webkit-touch-callout: none;
  /* option */

  -webkit-transition: all 0.2s ease-in-out;
  -moz-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  -ms-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
}
.es-carousel ul li.selected a {
  border-color: #0069D6;
  opacity: 1.0;
}
.es-carousel ul li a img {
  display: block;
  border: none;
  max-height: 100%;
  max-width: 100%;
}
.es-nav span {
  position: absolute;
  top: 0px;
  left: 0px;
  background-image: url(../img/ui/icon_slider_left.png);
  background-color: #efefef;
  background-position: 4px 50%;
  background-repeat: no-repeat;
  width: 20px;
  height: 100%;
  text-indent: -9000px;
  cursor: pointer;
  opacity: 0.3;
  -moz-border-radius-topright: 0px;
  -moz-border-radius-topleft: 4px;
  -moz-border-radius-bottomleft: 4px;
  -moz-border-radius-bottomright: 0px;
  -webkit-border-radius: 4px 0px 0px 4px;
  border-radius: 4px 0px 0px 4px;
}
.es-nav span.es-nav-next {
  right: 0px;
  left: auto;
  background-image: url(../img/ui/icon_slider_right.png);
  -moz-border-radius-topleft: 0px;
  -moz-border-radius-topright: 4px;
  -moz-border-radius-bottomright: 4px;
  -moz-border-radius-bottomleft: 0px;
  -webkit-border-radius: 0px 4px 4px 0px;
  border-radius: 0px 4px 4px 0px;
}
.es-nav span:hover {
  background-color: #ddd;
}
/* Accordion */
.accordion dt {
  display: block;
  background-image: url(../img/ui/icon_plus.png);
  background-position: 0px 2px;
  background-repeat: no-repeat;
  padding-left: 26px;
  padding-bottom: 9px;
  margin-top: 9px;
  color: #0088cc;
  cursor: pointer;
  border-bottom: 1px solid #999999;
}
.accordion .open {
  background-image: url(../img/ui/icon_minus.png);
}
.accordion dd {
  width: 100%;
  margin: 0px;
  padding: 0px;
}
.accordion dd div {
  /*      .well();*/

}
/* Gallery */
.rg-image-wrapper {
  position: relative;
  padding: 20px 30px;
  border: solid 1px #ddd;
  /*  background:transparent url(../ResponsiveGallery/black.png) repeat top left;*/

  background: #fff;
  -moz-border-radius: 3px;
  -webkit-border-radius: 3px;
  border-radius: 3px;
  min-height: 20px;
  margin-bottom: 20px;
}
.rg-image {
  position: relative;
  text-align: center;
  line-height: 0px;
}
.rg-image a {
  display: block;
}
.rg-image img {
  max-height: 100%;
  max-width: 100%;
  max-height: 250px;
}
.rg-image-nav a {
  position: absolute;
  top: 0px;
  left: 0px;
  background-image: url(../img/ui/icon_slider_left.png);
  background-color: #fff;
  background-position: 4px 50%;
  background-repeat: no-repeat;
  width: 20px;
  height: 100%;
  text-indent: -9000px;
  cursor: pointer;
  opacity: 0.8;
  outline: none;
  border-right: 1px solid #ddd;
}
.rg-image-nav a.rg-image-nav-next {
  right: 0px;
  left: auto;
  background-image: url(../img/ui/icon_slider_right.png);
  background-position: 4px 50%;
  background-repeat: no-repeat;
  -moz-border-radius: 0px 3px 3px 0px;
  -webkit-border-radius: 0px 3px 3px 0px;
  border-radius: 0px 3px 3px 0px;
  border-left: 1px solid #ddd;
  border-right-width: 0px;
}
.rg-image-nav a:hover {
  background-color: #ddd;
}
.rg-caption {
  text-align: center;
  margin-top: 15px;
  position: relative;
}
.rg-caption p {
  font-size: 0.846em;
  letter-spacing: 2px;
  font-family: 'Trebuchet MS', 'Myriad Pro', Arial, sans-serif;
  line-height: 16px;
  padding: 0 15px;
  text-transform: uppercase;
}
.rg-view {
  height: 30px;
}
.rg-view a {
  display: block;
  float: right;
  width: 16px;
  height: 16px;
  margin-right: 3px;
  background: #464646 url(../../responsivegallery/views.png) no-repeat top left;
  border: 3px solid #464646;
  opacity: 0.8;
}
.rg-view a:hover {
  opacity: 1.0;
}
.rg-view a.rg-view-full {
  background-position: 0px 0px;
}
.rg-view a.rg-view-selected {
  background-color: #6f6f6f;
  border-color: #6f6f6f;
}
.rg-view a.rg-view-thumbs {
  background-position: 0px -16px;
}
.rg-loading {
  width: 46px;
  height: 46px;
  position: absolute;
  top: 50%;
  left: 50%;
  /*  background:#000 url(../responsivegallery/ajax-loader.gif) no-repeat center center;*/

  margin: -23px 0px 0px -23px;
  z-index: 100;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  border-radius: 10px;
  opacity: 0.7;
}
/* Modal modifications */
.large-content {
  height: 300px;
  overflow: auto;
  padding-right: 30px;
}
.sub-header h2 small {
  *zoom: 1;
}
.sub-header h2 small:before,
.sub-header h2 small:after {
  display: table;
  content: "";
}
.sub-header h2 small:after {
  clear: both;
}
.sub-header h2 a {
  float: right;
  line-height: 36px;
}
/* Star Rating Default */
.star {
  clear: both;
  display: block;
  padding-left: 110px;
  background: url(../img/ui/bg-stars.png) 0px -4px no-repeat;
  height: 18px;
  line-height: 18px;
}
.star.One {
  background-position: 0px -26px;
}
.star.Two {
  background-position: 0px -48px;
}
.star.Three {
  background-position: 0px -70px;
}
.star.Four {
  background-position: 0px -92px;
}
.star.Five {
  background-position: 0px -114px;
}
/* Star Rating Small */
.product_pod .star {
  padding-left: 0px;
  text-indent: -9999px;
  background: url(../img/ui/bg-stars-small.png) 0px -4px no-repeat;
  height: 11px;
  line-height: 11px;
  width: 65px;
  margin: 0px auto 4px;
}
.product_pod .star.One {
  background-position: 0px -18px;
}
.product_pod .star.Two {
  background-position: 0px -32px;
}
.product_pod .star.Three {
  background-position: 0px -47px;
}
.product_pod .star.Four {
  background-position: 0px -61px;
}
.product_pod .star.Five {
  background-position: 0px -75px;
}
/*style guide*/
.swatch {
  display: inline-block;
  width: 30px;
  height: 20px;
  margin: -6px 0;
  background: #555555;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.swatch-col {
  width: 30px;
}
.test-opacity {
  opacity: 0.5;
  filter: alpha(opacity=50);
}
.test-square {
  width: 25px;
  height: 25px;
}
.test-size {
  width: 7px;
  height: 25px;
}
.test-center {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
.test-radius {
  -webkit-border-radius: 10px;
  -moz-border-radius: 10px;
  border-radius: 10px;
}
.test-shadow {
  -webkit-box-shadow: 2px 2px 3px rgba(0, 0, 0, 0.5);
  -moz-box-shadow: 2px 2px 3px rgba(0, 0, 0, 0.5);
  box-shadow: 2px 2px 3px rgba(0, 0, 0, 0.5);
}
.test-transition {
  -webkit-transition: all 1s ease-in-out;
  -moz-transition: all 1s ease-in-out;
  -ms-transition: all 1s ease-in-out;
  -o-transition: all 1s ease-in-out;
  transition: all 1s ease-in-out;
}
.test-transition:hover {
  background: #46a546;
}
.test-rotation {
  -webkit-transform: rotate(50deg);
  -moz-transform: rotate(50deg);
  -ms-transform: rotate(50deg);
  -o-transform: rotate(50deg);
  transform: rotate(50deg);
}
.test-scale {
  -webkit-transform: scale(0.5);
  -moz-transform: scale(0.5);
  -ms-transform: scale(0.5);
  -o-transform: scale(0.5);
  transform: scale(0.5);
}
.test-translate {
  -webkit-transform: translate(15px, 5px);
  -moz-transform: translate(15px, 5px);
  -ms-transform: translate(15px, 5px);
  -o-transform: translate(15px, 5px);
  transform: translate(15px, 5px);
}
.test-clip {
  border: 5px solid #ffc40d;
  padding: 5px;
  -webkit-background-clip: content;
  -moz-background-clip: content;
  background-clip: content;
}
.test-bgsize {
  background: url('http://placehold.it/260x180') no-repeat 0 0 #46a546;
  -webkit-background-size: 10px auto;
  -moz-background-size: 10px auto;
  -o-background-size: 10px auto;
  background-size: 10px auto;
}
.test-sizing {
  border: 3px solid #9d261d;
  padding: 2px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.test-select {
  -webkit-user-select: none;
  -moz-user-select: none;
  -o-user-select: none;
  user-select: none;
}
.test-resizable {
  resize: both;
  overflow: auto;
  max-width: 40px;
  max-height: 40px;
}
.test-column {
  -webkit-column-count: 3;
  -moz-column-count: 3;
  column-count: 3;
  -webkit-column-gap: 10;
  -moz-column-gap: 10;
  column-gap: 10;
}
.test-transback {
  background-color: rgba(70, 164, 70, 0.5);
}
.test-transborder {
  border: 3px solid #000000;
  border-color: rgba(155, 37, 28, 0.5);
  -webkit-background-clip: padding-box;
  -moz-background-clip: padding-box;
  background-clip: padding-box;
}
.test-gradvert {
  background-color: #90b12f;
  background-image: -moz-linear-gradient(top, #46a546, #ffc40d);
  background-image: -ms-linear-gradient(top, #46a546, #ffc40d);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#46a546), to(#ffc40d));
  background-image: -webkit-linear-gradient(top, #46a546, #ffc40d);
  background-image: -o-linear-gradient(top, #46a546, #ffc40d);
  background-image: linear-gradient(top, #46a546, #ffc40d);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#46a546', endColorstr='#ffc40d', GradientType=0);
}
.test-gradhoriz {
  background-color: #ffc40d;
  background-image: -moz-linear-gradient(left, #46a546, #ffc40d);
  background-image: -ms-linear-gradient(left, #46a546, #ffc40d);
  background-image: -webkit-gradient(linear, 0 0, 100% 0, from(#46a546), to(#ffc40d));
  background-image: -webkit-linear-gradient(left, #46a546, #ffc40d);
  background-image: -o-linear-gradient(left, #46a546, #ffc40d);
  background-image: linear-gradient(left, #46a546, #ffc40d);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#46a546', endColorstr='#ffc40d', GradientType=1);
}
.test-graddirect {
  background-color: #ffc40d;
  background-repeat: repeat-x;
  background-image: -moz-linear-gradient(45deg, #46a546, #ffc40d);
  background-image: -ms-linear-gradient(45deg, #46a546, #ffc40d);
  background-image: -webkit-linear-gradient(45deg, #46a546, #ffc40d);
  background-image: -o-linear-gradient(45deg, #46a546, #ffc40d);
  background-image: linear-gradient(45deg, #46a546, #ffc40d);
}
.test-gradthreecolors {
  background-color: #d6d6d6;
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#000000), color-stop(50%, #ffffff), to(#333333));
  background-image: -webkit-linear-gradient(#000000, #ffffff 50%, #333333);
  background-image: -moz-linear-gradient(top, #000000, #ffffff 50%, #333333);
  background-image: -ms-linear-gradient(#000000, #ffffff 50%, #333333);
  background-image: -o-linear-gradient(#000000, #ffffff 50%, #333333);
  background-image: linear-gradient(#000000, #ffffff 50%, #333333);
  background-repeat: no-repeat;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#000000', endColorstr='#333333', GradientType=0);
}
.test-gradradial {
  background-color: #049cdb;
  background-image: -webkit-gradient(radial, center center, 0, center center, 460, from(#ffc40d), to(#049cdb));
  background-image: -webkit-radial-gradient(circle, #ffc40d, #049cdb);
  background-image: -moz-radial-gradient(circle, #ffc40d, #049cdb);
  background-image: -ms-radial-gradient(circle, #ffc40d, #049cdb);
  background-repeat: no-repeat;
}
.test-gradstriped {
  background-color: #049cdb;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -ms-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
/*** Promotional block styles ***/
.sidebar .promotion_single .row-fluid > [class*="span"] {
  float: none;
  width: auto;
}
/*** Badge styles ***/
.group-price {
  position: absolute;
  top: 2%;
  left: 0px;
  border: 1px solid #f89406;
  text-transform: uppercase;
  background-color: #ffffff;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-shadow: 2px 2px 3px rgba(0, 0, 0, 0.3);
  -moz-box-shadow: 2px 2px 3px rgba(0, 0, 0, 0.3);
  box-shadow: 2px 2px 3px rgba(0, 0, 0, 0.3);
  background-color: #f5f5f5;
  background-image: -moz-linear-gradient(top, #eeeeee, #ffffff);
  background-image: -ms-linear-gradient(top, #eeeeee, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #eeeeee, #ffffff);
  background-image: -o-linear-gradient(top, #eeeeee, #ffffff);
  background-image: linear-gradient(top, #eeeeee, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#ffffff', GradientType=0);
}
.group-price span {
  display: block;
  font-size: 10px;
  background-color: #f89406;
  padding: 1px 2px;
  color: #ffffff;
}
.group-price strong {
  padding: 8px 15px;
  display: block;
}
.badge_container,
.badge_container:before,
.badge_container:after,
.badge_container .badge,
.badge_container .badge:before,
.badge_container .badge:after {
  height: 2.5em;
  width: 2.5em;
  background-color: #DA4F49;
  background-size: 2.5em;
}
.badge_container:before,
.badge_container:after,
.badge_container .badge:before,
.badge_container .badge:after {
  content: "";
  position: absolute;
}
.badge_container {
  margin: 0 auto;
  /* Centering for demo */

  position: absolute;
  /* Context */

  top: 1.5em;
  left: 1.5em;
  z-index: 9;
  -webkit-transform: rotate(-45deg);
  -moz-transform: rotate(-45deg);
  -ms-transform: rotate(-45deg);
  -o-transform: rotate(-45deg);
  transform: rotate(-45deg);
}
.badge_container:before {
  top: 0;
  left: 0;
  -webkit-transform: rotate(-30deg);
  -moz-transform: rotate(-30deg);
  -ms-transform: rotate(-30deg);
  -o-transform: rotate(-30deg);
  transform: rotate(-30deg);
}
.badge_container:after {
  top: 0;
  left: 0;
  -webkit-transform: rotate(-15deg);
  -moz-transform: rotate(-15deg);
  -ms-transform: rotate(-15deg);
  -o-transform: rotate(-15deg);
  transform: rotate(-15deg);
}
.badge_container .badge {
  padding: .5em 0em;
  height: 1.5em;
  /* height minus padding */

  position: absolute;
  bottom: 0;
  right: 0;
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  transform: rotate(45deg);
  z-index: 1;
  /* important so the text shows up */

}
.badge_container .badge .label {
  background-color: transparent;
}
.badge_container .badge:before {
  top: 0;
  left: 0;
  -webkit-transform: rotate(60deg);
  -moz-transform: rotate(60deg);
  -ms-transform: rotate(60deg);
  -o-transform: rotate(60deg);
  transform: rotate(60deg);
}
.badge_container .badge:after {
  top: 0;
  left: 0;
  -webkit-transform: rotate(75deg);
  -moz-transform: rotate(75deg);
  -ms-transform: rotate(75deg);
  -o-transform: rotate(75deg);
  transform: rotate(75deg);
}
.badge_container .badge span {
  position: relative;
  z-index: 100;
  display: block;
  text-align: center;
  color: #fff;
  font-size: 0.6em;
  line-height: 0.8em;
  text-transform: uppercase;
}
.badge_container .badge span.number {
  font-weight: bold;
  font-size: 0.5em;
  line-height: .4em;
  color: #f2f2f2;
}
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
.hide {
  display: none;
}
.show {
  display: block;
}
.invisible {
  visibility: hidden;
}
