{% extends 'layout.html' %}
{% load currency_filters %}
{% load thumbnail %}
{% load i18n %}

{% block title %}
"{{ query }}" | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
	<li>
	<a href="{% url promotions:home %}">{% trans "Home" %}</a>
	<span class="divider">/</span>
	</li>
	<li>
	{% trans "Search" %}
	<span class="divider">/</span>
	</li>
	<li class="active"><a href=".">{% blocktrans with q=query%}"{{ q }}"{% endblocktrans %}</a></li>
</ul>
{% endblock %}

{% block header%}
<div class="page-header">
	<h1>{% trans 'Search for' %} '{{ query }}'</h1>
</div>
{% endblock %}

{% block content %}

{% if suggestion %}
{% trans 'Did you mean' %} <a href="{% url search:search %}?q={{ suggestion }}">{{ suggestion }}</a>?
{% endif %}

{% if page.object_list %}
<ol class="products vertical three">
	{% for result in page.object_list %}
	{% include "catalogue/partials/product.html" with product=result.object %}
	{% endfor %}
</ol>
{% else %}
<p>{% trans 'No search results found.' %}</p>
{% endif %}

{% if page_obj %}
{% include "catalogue/partials/pagination.html" %}
{% endif %}

{% endblock %}