/*  Procduct columns*/
.five li {
    width:@fifth;
}
.four li {
    width:@quart;
}
.three li {
    width:@third;
}
.two li {
    width:@half
}
.one li {
    width:@full;
}
.five li,
.four li,
.three li,
.two li,
.one li {
  li {
    width:auto;
  }
}
.products {
  .horiz_col;
}
.product_pod {
  padding:8%;
  position:relative;
  height:375px;
  overflow:hidden;
  text-align:center;
  .clearfix();
  & p {
    margin-bottom:0;
  }
  h3 {
    font-size:1em;
    margin-bottom:0;
    line-height:@baseLineHeight;
    a {
      line-height:@baseLineHeight;
    }
  }
  h4 {
    .clearfix();
    margin-bottom: @baseLineHeight;
    margin-top: @baseLineHeight / 2;
    line-height:@baseLineHeight;
    font-size:@baseFontSize + 3;
    /*span {
          float:right;
        }
        del {
          float:left;
          font-size:0.611em;
          font-weight:normal;
          color:lighten(@grayDark, 40%);
        }*/
  }
  .avaliability {
    margin-bottom:@baseLineHeight / 2;
    text-align:center;
  }
  button {
    width:100%;
  }
  .product_price {
    position:absolute;
    bottom:8%;
    left:8%;
    width:84%;
    form {
      margin-bottom:0px;
      input#id_quantity,
      #id_product_id {
        width:90%;
      }
      label {
        display:none;
      }
    }
    .btn {
      padding-left:0px;
      padding-right:0px;
      width:100%;
    }
  }
}
/* carosel product list mods */
.es-carousel {
  .product_pod {
    height:250px;
    .product_price {
      bottom:0px;
    }
  } 
}
/* Product list image container */
.image_container {
  width:100%;
  height:125px;
  overflow:hidden;
  text-align: center;
  margin-bottom: @baseLineHeight / 2;
  position:relative;
  img {
/*    height:100%;*/
    max-height:125px;
    width:auto;
    margin:0px auto;
  }
}
/* For vertical product lists ADD class vertical */
.products.vertical {
  li {
    margin-bottom:@baseLineHeight;
    .product_pod {
      padding:0px;
      .image_container {
        width:@quart;
        float:left;
        margin-right:15px;
        margin-bottom:0px;
      }
      .avaliability {
        text-align:left;
      }
      .product_price {
        position:static;
        width:auto;
        h4 {
          display:inline;
          span, del {
            float:none;
          }
        }
        .btn {
           width:auto;
           display:block;
           padding: 5px 14px 6px;
           margin-top:5px;
        }
      }
    }
  }
}
.products.three.vertical,
.products.four.vertical,
.products.five.vertical {
  li {
    width:auto;
    float:none;
    border-bottom:1px solid @grayLighter;
    padding-bottom:@baseLineHeight;
      .product_pod {
        height: auto;
      }
  }
}
.products.two.vertical {
  li {
    .product_pod {
      height: auto;
    }
  }
  li:nth-child(2n-1) {
    clear:both;
  }
}