{% load i18n %}
<div id="top_page" class="navbar accounts">
	<div class="navbar-inner">
		<div class="container-fluid">
			<ul class="nav pull-right">
				{% if user.is_authenticated %}
				    {% if user.get_full_name %}
					<li><div>{% trans "Welcome" %} <em>{{ user.get_full_name }}</em></div></li>
					{% endif %}
					<li> <a href="{% url customer:summary %}" class="app-ico ico_profile">{% trans "Account" %}</a></li>
					<li><a href="{% url customer:logout %}" class="app-ico ico_logout">{% trans "Logout" %}</a></li>
					{% if user.is_staff %}
					<li><a href="{% url dashboard:index %}" class="app-ico ico_settings">{% trans "Dashboard" %}</a></li>
					{% endif %}
				{% else %}
				<li><a href="{% url customer:login %}" class="app-ico ico_logout">{% trans "Login" %}</a></li>
				{% endif %}
			</ul>
		</div>
    </div><!-- /navbar-inner -->
</div><!-- /navbar -->