{% extends "layout_2_col.html" %}
{% load i18n %}
{% load currency_filters %}

{% block column_left %} 
   <div class="well" style="padding: 8px 0;">
       {% load flatpages %}
       <ul class="nav nav-list">
		   <li class="nav-header">{% trans "Pages" %}</li>
           {% get_flatpages '/help/' as flatpages %}
           {% for page in flatpages %}
           <li><a href="{{ page.url }}">{{ page.title }}</a></li>
           {% endfor %}
       </ul>
   </div>
{% endblock %}

{% block flatpage %}
    <div class="sub-header">
        <h1>{{ flatpage.title }}</h1>
    </div>
    {{ flatpage.content }}
    {% load flatpages %}
    {% get_flatpages '/help/' as flatpages %}
    <dl class="accordion">
        {% for page in flatpages %}
            <dt>{{ page.title }}</dt>
            <dd>
                <div>
                    {{ page.content|safe }}
                </div>
            </dd>
        {% endfor %}
    </dl>
{% endblock %}