{% extends 'dashboard/layout.html' %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url dashboard:index %}">Dashboard</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% if parent %}{% url dashboard:catalogue-category-detail-list pk=parent.pk %}{% else %}{% url dashboard:catalogue-category-list %}{% endif %}">Categories</a>
        <span class="divider">/</span>
    </li>
    <li class="active"><a href=".">Delete category?</a></li>
</ul>
{% endblock %}

{% block header %}
<div class="page-header">
    <h1>Delete category?</h1>
</div>
{% endblock header%}

{% block dashboard_content %}
<form action="." method="post">
    {% csrf_token %}
    {{ form }}
    <p>Delete category <strong>{{ object.name }}</strong> - are you sure?</p>
    <div class="form-actions">
        <button type="submit" class="btn btn-danger">Delete</button>
        or <a href="{% if parent %}{% url dashboard:catalogue-category-detail-list pk=parent.pk %}{% else %}{% url dashboard:catalogue-category-list %}{% endif %}">cancel</a>
    </div>
</form>
{% endblock %}
