/*================
Screen styles for the Snowcone icon webfont
Version 1.0
Author: Tangent Snowball FED team
Created: 01.06.2012 (US format date)
==================*/ 

/*========
[=1:Set webfont stack for the icons]
======== */
	@font-face {
	    font-family: 'SnowconeRegular';
	    src: url('../fonts/snowcone-regular-webfont.eot');
	    src: url('../fonts/snowcone-regular-webfont.eot?#iefix') format('embedded-opentype'),
	         url('../fonts/snowcone-regular-webfont.woff') format('woff'),
	         url('../fonts/snowcone-regular-webfont.ttf') format('truetype'),
	         url('../fonts/snowcone-regular-webfont.svg#SnowconeRegular') format('svg');
	    font-weight: normal;
	    font-style: normal;
	}                           

/*========
[=2:Set classes to trigger icons]
======== */ 
	.app-ico:before{font-family:'SnowconeRegular';padding-right:5px} 
	.app-ico.ico_alert:before{content:"A";}
	.app-ico.ico_cross:before,.app-ico.outofstock:before{content:"B";}
	.app-ico.ico_tick:before,.app-ico.instock:before{content:"C";}
	.app-ico.ico_expand:before{content:"D";}
	.app-ico.ico_contract:before{content:"E";}
	.app-ico.ico_view:before{content:"F";}
	.app-ico.ico_sync:before{content:"G";}
	.app-ico.ico_home:before{content:"H";}
	.app-ico.ico_outline_down:before{content:"I";}
	.app-ico.ico_outline_up:before{content:"J";}
	.app-ico.ico_outline_right:before{content:"K";}
	.app-ico.ico_outline_left:before{content:"L";}
	.app-ico.ico_stop:before{content:"M";}
	.app-ico.ico_mapmarker:before{content:"N";}
	.app-ico.ico_favourite:before{content:"O";}
	.app-ico.ico_profile:before{content:"P";}
	.app-ico.ico_magnify:before{content:"Q";}
	.app-ico.ico_comment:before{content:"R";}
	.app-ico.ico_settings:before{content:"S";}
	.app-ico.ico_edit:before{content:"T";}
	.app-ico.ico_email:before{content:"U";}
	.app-ico.ico_shop_bag:before{content:"V";}
	.app-ico.ico_logout:before{content:"W";} 
	.app-ico.ico_heart:before{content:"X";} 
	.app-ico.ico_rss:before{content:"Z";} 
	.app-ico.ico_link:before{content:"a";} 
	.app-ico.ico_fill_down:before{content:"b";} 
	.app-ico.ico_fill_up:before{content:"c";} 
	.app-ico.ico_fill_right:before{content:"d";} 
	.app-ico.ico_fill_left:before{content:"e";} 
	.app-ico.ico_facebook:before{content:"f";} 
	.app-ico.ico_twitter:before{content:"g";} 
	.app-ico.ico_googleplus:before{content:"h";} 
	.app-ico.ico_blacklist:before{content:"i";} 
	.app-ico.ico_twitter_bird:before{content:"t";} 
	.app-ico.ico_twitter_plain:before{content:"u";} 
	.app-ico.ico_tag:before{content:"t";} 
	.app-ico.ico_speedo:before{content:"y";}  
	.app-ico.ico_tangentsnowball:before{content:"z";}  		

/*========
[=3:Ensure legacy browsers still see icons]
======== */ 		
	.app-legacy_ico{font-family:'SnowconeRegular';margin-right:4px;}

	


