{% extends "layout.html" %}
{% load currency_filters %}
{% load i18n %}

{% block header %}
    <h2>{% trans "Saved Basket" %}</h2>
{% endblock header %}

{% block content %}
    {% for item in saved_items %}
    <p>{{ item }}</p>
    {% endfor %}
{% endblock content %}
