{% load i18n %}
<form method="get" action="{% url search:search %}" class="form-search navbar-search pull-right">
    {# {{ search_form.q.label_tag }} #}
    {{ search_form.q }}
	<input type="submit" value="{% trans "Search" %}" class="btn" />
</form>