@import url("bootstrap.min.css");
@import url("snowcone.css");
.clearfix{*zoom:1;}.clearfix:before,.clearfix:after{display:table;content:"";}
.clearfix:after{clear:both;}
.hide-text{overflow:hidden;text-indent:100%;white-space:nowrap;}
.input-block-level{display:block;width:100%;min-height:28px;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;-ms-box-sizing:border-box;box-sizing:border-box;}
body{background:#fff;}
.container-fluid{padding-left:20px;padding-right:20px;max-width:100%;}
.navbar-fixed-top .navbar-inner{padding-left:20px;padding-right:20px;}
.navbar .nav>li span{display:block;padding:10px;}
.subnav-fixed{position:fixed;right:0;left:0;z-index:1030;top:40px;-webkit-box-shadow:0 1px 5px rgba(0, 0, 0, 0.1);-moz-box-shadow:0 1px 5px rgba(0, 0, 0, 0.1);box-shadow:0 1px 5px rgba(0, 0, 0, 0.1);border-bottom:1px solid #D5D5D5;}
.subnav{background-color:#f2f2f2;background-image:-moz-linear-gradient(top, #f5f5f5, #eeeeee);background-image:-ms-linear-gradient(top, #f5f5f5, #eeeeee);background-image:-webkit-gradient(linear, 0 0, 0 100%, from(#f5f5f5), to(#eeeeee));background-image:-webkit-linear-gradient(top, #f5f5f5, #eeeeee);background-image:-o-linear-gradient(top, #f5f5f5, #eeeeee);background-image:linear-gradient(top, #f5f5f5, #eeeeee);background-repeat:repeat-x;filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#f5f5f5', endColorstr='#eeeeee', GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false) !important;height:36px;width:100%;}
.subnav .nav{padding-left:20px;padding-right:20px;}.subnav .nav>li>a{margin:0;padding-top:11px;padding-bottom:11px;border-left:1px solid #f5f5f5;border-right:1px solid #E5E5E5;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0;}
.reports .subnav li.Reports>a,.orders .subnav li.Manage.orders>a,.users .subnav li.Users>a,.content-blocks .subnav li.Content.blocks>a,.catalogue .subnav li.Catalogue>a,.subnav .nav>.active>a,.subnav .nav>.active>a:hover{padding-left:13px;color:#777;background-color:#E9E9E9;border-right-color:#DDD;border-left:0;-webkit-box-shadow:inset 0 3px 5px rgba(0, 0, 0, 0.05);-moz-box-shadow:inset 0 3px 5px rgba(0, 0, 0, 0.05);box-shadow:inset 0 3px 5px rgba(0, 0, 0, 0.05);}
.breadcrumb{margin-top:100px;}
.content{background:#fff;}.content .page-content{padding:30px 0px;}
button{background-color:transparent;}
.primary-nav,.primary-nav ul{margin:0px;padding:0px;}
.page-header{background-color:#ffffff;padding:10px 20px 10px 0px;margin-bottom:0px;}.page-header h1{}
h3{margin-bottom:4.5px;}
caption{font-weight:bold;font-size:14px;margin-bottom:8px;}
.search-adv .control-group.pull-left>label{width:100px;}
.search-adv .control-group.pull-left .controls{margin-left:120px;}.search-adv .control-group.pull-left .controls>label{padding-left:0px;padding-top:0px;}
.search-adv .control-group.pull-left .controls .radio ul{padding:0px;margin:0px;*zoom:1;}.search-adv .control-group.pull-left .controls .radio ul:before,.search-adv .control-group.pull-left .controls .radio ul:after{display:table;content:"";}
.search-adv .control-group.pull-left .controls .radio ul:after{clear:both;}
.search-adv .control-group.pull-left .controls .radio ul>li{list-style:none;}
.search-adv .control-group.pull-left .controls .radio ul li{float:left;}.search-adv .control-group.pull-left .controls .radio ul li li{float:none;}
.search-adv .control-group.pull-left .controls .radio ul li label{display:inline-block;padding-top:5px;margin-bottom:0;vertical-align:middle;margin-left:10px;padding-left:18px;}
.product-new .form-inline.pull-left{margin-right:15px;}
.no-float{float:none;}
.control-group.pull-left.no-float>label{width:140px;}
.control-group.pull-left.no-float .controls{margin-left:160px;}
.pull-left.btn{margin-left:20px;}
.pull-left.no-float.btn{margin-left:160px;}
.page-header.action{*zoom:1;margin-bottom:0px;}.page-header.action:before,.page-header.action:after{display:table;content:"";}
.page-header.action:after{clear:both;}
.page-header.action .open .dropdown-toggle{color:#fff;background:#444;}
.page-header.action .btn{margin-left:10px;}
.page-header.action .tabs .dropdown-menu{top:48px;left:10px;}
.page-header.action .tabs{border-width:0px;margin-bottom:0px;}
.page-header.action h1,.page-header.action h2{float:left;margin-bottom:0px;}
.page-header.action .orders_search{clear:both;margin-bottom:18px;}
.page-header.action .pull_out.viewed{background-color:rgba(0, 0, 0, 0.05);margin-bottom:18px;}
.page-header.action .pull_out,.page-header.action a.dd_menu{display:block;float:left;line-height:32px;font-size:18px;margin-left:10px;padding:4px 10px;color:#0088cc;}
.page-header.action .pull_out.viewed,.page-header.action a.dd_menu.viewed{-moz-border-radius-topleft:4px;-moz-border-radius-topright:4px;-moz-border-radius-bottomright:0px;-moz-border-radius-bottomleft:0px;-webkit-border-radius:4px 4px 0px 0px;border-radius:4px 4px 0px 0px;}
.page-header.action a.dd_menu:hover{background:#444;color:#fff;}
.controls ul{margin-left:0px;list-style:none;}
.icon:before{padding:7px 6px;background:#000000;background-color:rgba(0, 0, 0, 0.15);-webkit-border-radius:20px;-moz-border-radius:20px;border-radius:20px;color:#ffffff;margin-right:5px;}
.file_upload{*zoom:1;}.file_upload:before,.file_upload:after{display:table;content:"";}
.file_upload:after{clear:both;}
.file_upload form,.file_upload p{float:left;}
.file_upload label{width:auto;padding-top:0px;margin-right:10px;}
.file_upload input{line-height:18px;background:none;}
.alert-message.block-message.file_upload p{margin-right:10px;}
.order_table label{width:auto;margin-left:20px;line-height:27px;float:left;margin-right:10px;}.order_table label:first-child{margin-left:10px;}
.order_table table{margin-top:18px;}
.order_table .row{margin-left:0px;}
.tabs.product_managment{margin-bottom:0px;}.tabs.product_managment li.active a{background-color:#efefef;}
.tabbable.dashboard .nav{margin-bottom:0px;}
.tabbable.dashboard .nav-tabs>li>a{background:#f5f5f5;background-color:#e0e0e0;background-image:-moz-linear-gradient(top, #cccccc, #ffffff);background-image:-ms-linear-gradient(top, #cccccc, #ffffff);background-image:-webkit-gradient(linear, 0 0, 0 100%, from(#cccccc), to(#ffffff));background-image:-webkit-linear-gradient(top, #cccccc, #ffffff);background-image:-o-linear-gradient(top, #cccccc, #ffffff);background-image:linear-gradient(top, #cccccc, #ffffff);background-repeat:repeat-x;filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#cccccc', endColorstr='#ffffff', GradientType=0);border:1px solid #DDD;margin:6px 10px 0 0;color:#555555;font-weight:bold;text-shadow:1px 1px 0 #fff;}
.tabbable.dashboard .nav-tabs>li.active a,.tabbable.dashboard .nav-tabs>li>a:hover{background:#f5f5f5;border-bottom-color:transparent;background-color:#f5f5f5;background-image:-moz-linear-gradient(top, #eeeeee, #ffffff);background-image:-ms-linear-gradient(top, #eeeeee, #ffffff);background-image:-webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#ffffff));background-image:-webkit-linear-gradient(top, #eeeeee, #ffffff);background-image:-o-linear-gradient(top, #eeeeee, #ffffff);background-image:linear-gradient(top, #eeeeee, #ffffff);background-repeat:repeat-x;filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#ffffff', GradientType=0);border-bottom:1px solid #fff;outline:none;font-weight:bold;color:#0088CC;}
.tabbable.dashboard .tab-content{display:block;width:auto;padding:18px;border:1px solid #e1e1e1;border-top-width:0px;background:#fff;-webkit-border-bottom-right-radius:5px;-webkit-border-bottom-left-radius:5px;-moz-border-radius-bottomright:5px;-moz-border-radius-bottomleft:5px;border-bottom-right-radius:5px;border-bottom-left-radius:5px;}
.fields-full input[type=text],.fields-full textarea{width:99%;}
.well{*zoom:1;}.well:before,.well:after{display:table;content:"";}
.well:after{clear:both;}
.well-success{background-color:#dff0d8;border-color:#d6e9c6;}
.well-danger{background-color:#f2dede;border-color:#eed3d7;}
.well-info{background-color:#d9edf7;border-color:#bce8f1;}
.well-blank{background-color:#ffffff;border-color:rgba(0, 0, 0, 0.1);}
#order-graph{position:relative;margin-bottom:5em;width:99%;height:330px;}
.bar-caption{position:absolute;color:#999999;text-align:center;opacity:0.4;top:50%;left:50%;}
.bar-y-axis{position:absolute;top:16px;width:5em;margin:0;padding:0;float:left;display:inline;}
.bar-y-axis li{list-style:none;height:33px;float:right;}
.bar-chart,.bar-chart dt,.bar-chart dd{margin:0;padding:0;}
.bar-chart{position:absolute;top:0;left:0;width:98%;height:300px;padding-left:5em;}
.bar-chart dd{position:relative;float:left;width:4%;height:330px;margin-top:22px;}
.bar-chart dd em{position:absolute;bottom:-2em;right:0;}
.bar-chart span{position:absolute;display:block;width:90%;bottom:0;left:0;z-index:1;color:#555555;text-align:center;text-decoration:none;}
.bar-chart span p{position:relative;top:1em;display:inline;padding:3px;color:#333333;z-index:2;background-color:#ffffff;font-weight:bold;-moz-border-radius:3px;-webkit-border-radius:3px;-khtml-border-radius:3px;border-radius:3px;}
.bar-chart span{height:50%;background:#87e0fd;background:-moz-linear-gradient(-45deg, #87e0fd 0%, #53cbf1 40%, #05abe0 100%);background:-webkit-gradient(linear, left top, right bottom, color-stop(0%, #87e0fd), color-stop(40%, #53cbf1), color-stop(100%, #05abe0));background:-webkit-linear-gradient(-45deg, #87e0fd 0%, #53cbf1 40%, #05abe0 100%);background:-o-linear-gradient(-45deg, #87e0fd 0%, #53cbf1 40%, #05abe0 100%);background:-ms-linear-gradient(-45deg, #87e0fd 0%, #53cbf1 40%, #05abe0 100%);background:linear-gradient(-45deg, #87e0fd 0%, #53cbf1 40%, #05abe0 100%);filter:progid:dximagetransform.microsoft.gradient(startColorstr='#87e0fd', endColorstr='#05abe0', GradientType=1);-moz-border-radius:5px;-webkit-border-radius:5px;-khtml-border-radius:5px;border-radius:5px;}
#ui-datepicker-div{background:#FFFFFF;width:218px;box-shadow:2px 2px 2px #AAAAAA;}
#ui-datepicker-div .ui-datepicker-header{position:relative;padding:5px;text-align:center;background:#dddddd;font-weight:bold;}
#ui-datepicker-div .ui-datepicker-prev{position:absolute;top:6px;left:6px;cursor:pointer;}
#ui-datepicker-div .ui-datepicker-next{position:absolute;top:6px;right:6px;cursor:pointer;}
#ui-datepicker-div table{width:100%;}
#ui-datepicker-div th,#ui-datepicker-div td{padding:0px;text-align:center;}
#ui-datepicker-div th{padding:4px;}
#ui-datepicker-div td a{padding:4px;display:block;}
#ui-datepicker-div td .ui-state-highlight{background:#eeeeee;}
#ui-datepicker-div td .ui-state-active{color:#FFFFFF;background:#0088CC;}
.errorlist{margin:0 0 0 20px;padding:0 0 10px 0;color:#B94A48;}.errorlist li{padding:0 0 5px 0;list-style:none;}
.form-inline .help-block{display:inline-block;margin:0 20px 0 10px;}.form-inline .help-block li{list-style:none;color:#B94A48;}
