{% load basket_tags %}
{% load i18n %}

{% if product.is_available_to_buy %}
    {% basket_form request.basket product as basket_form %}
    <form action="{% url basket:add %}" method="post" class="form-stacked">
        {% csrf_token %}
        {% include "partials/form_fields.html" with form=basket_form %}

        <div class="form-actions">
			<button type="submit" class="btn btn-large btn-primary" value="Add to basket">{% trans "Add to basket" %}</button>
        </div>
    </form>
{% endif %}
