/*!
 * Bootstrap Responsive v2.0.0
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */

// Responsive.less
// For phone and tablet devices
// -------------------------------------------------------------


// REPEAT VARIABLES & MIXINS
// -------------------------
// Required since we compile the responsive stuff separately

@import "bootstrap/variables.less"; // Modify this for custom colors, font-sizes, etc
@import "bootstrap/mixins.less";
// Oscar variables and mixins
@import "page/osc_mixins.less"; // Kept separtate for bootstrap updates - but should be imported into bootstap mixins.


// RESPONSIVE CLASSES
// ------------------

// Hide from screenreaders and browsers
// Credit: HTML5 Boilerplate
.hidden {
  display: none;
  visibility: hidden;
}



// UP TO LANDSCAPE PHONE
// ---------------------

@media (max-width: 480px) {

  // Smooth out the collapsing/expanding nav
  .nav-collapse {
    -webkit-transform: translate3d(0, 0, 0); // activate the GPU
  }

  // Block level the page header small tag for readability
  .page-header h1 small {
    display: block;
    line-height: @baseLineHeight;
  }

  // Make span* classes full width
  input[class*="span"],
  select[class*="span"],
  textarea[class*="span"],
  .uneditable-input {
    display: block;
    width: 100%;
    height: 28px; /* Make inputs at least the height of their button counterpart */
    /* Makes inputs behave like true block-level elements */
    -webkit-box-sizing: border-box; /* Older Webkit */
       -moz-box-sizing: border-box; /* Older FF */
        -ms-box-sizing: border-box; /* IE8 */
            box-sizing: border-box; /* CSS3 spec*/
  }
  // But don't let it screw up prepend/append inputs
  .input-prepend input[class*="span"],
  .input-append input[class*="span"] {
    width: auto;
  }

  // Update checkboxes for iOS
  input[type="checkbox"],
  input[type="radio"] {
    border: 1px solid #ccc;
  }

  // Remove the horizontal form styles
  .form-horizontal .control-group > label {
    float: none;
    width: auto;
    padding-top: 0;
    text-align: left;
  }
  // Move over all input controls and content
  .form-horizontal .controls {
    margin-left: 0;
  }
  // Move the options list down to align with labels
  .form-horizontal .control-list {
    padding-top: 0; // has to be padding because margin collaspes
  }
  // Move over buttons in .form-actions to align with .controls
  .form-horizontal .form-actions {
    padding-left: 10px;
    padding-right: 10px;
  }
  // Modals
  .modal {
    position: absolute;
    top:   10px;
    left:  10px;
    right: 10px;
    width: auto;
    margin: 0;
    &.fade.in { top: auto; }
  }
  .modal-header .close {
    padding: 10px;
    margin: -10px;
  }

  // Carousel
  .carousel-caption {
    position: static;
  }
  // Navbar Accounts
  .navbar.accounts {
    margin-bottom:0px;
    .brand.hidden {
      display: inline;
      padding:6px 10px;
      font-size:18px;
    }
    .nav > li {
      div,
      &:last-child {
        display:none;
      }
    }
  }
  // Product floats
  .product_title,
  .product_assets,
  .product_description,
  .product_related,
  .review_content,
  .review_votes,
  .main,
  .products li,
  .five li,
  .four li,
  .three li,
  .two li,
  .product_pod .product_price,
  .footer_links li,
  .footer_links .top_page {
    float:none;
    margin:0px;
    width:auto;
    height:auto;
  }
  // Product
  .products {
    li {
      border-bottom:1px solid @grayLighter;
      padding-bottom:@baseLineHeight;
      margin-bottom:@baseLineHeight;
      .product_pod {
        margin-bottom:0px;
        height:auto!important;
        padding:0px;
        text-align:left;
        .star {
          clear:none;
          margin:0px;
        }
        .avaliability {
          text-align:left;
        }
        .group-price {
          position:static;
          border:none;
          color:@orange;
          text-transform:capitalize;
          background-color:none;
          .border-radius(none);
          .box-shadow(none);
          background:none;
          margin:0px;
          span {
            display:inline;
            font-size:@baseFontSize;
            background:none;
            padding:0px;
            color:inherit;
          }
          strong {
            padding:0px;
            display:inline;
          }
        }
        .product_price {
          position:static;
          h4 {
            margin-bottom:0px;
            display:inline;
            span, del {
              float:none;
            }
          }
          form {
            input#id_quantity {
              width: auto;
            }
            .btn {
              width:auto;
              display:block;
              padding: 5px 14px 6px;
              margin-top:5px;
            }
          }
          
        } 
        .image_container {
          width:@quart;
          float:right;
          margin-left:15px;
          margin-bottom:0px;
          img {
            height:auto;
          }
        }
      }
    }
  }
  // Reviews
  .star {
    padding-left:70px;
  	background:url(../img/ui/bg-stars-small.png) 0px -4px no-repeat;
  	height:11px;
  	line-height:11px;
  }
  .star.One {
  	background-position: 0px -18px;
  }
  .star.Two {
  	background-position: 0px -32px;
  }
  .star.Three {
  	background-position: 0px -47px;
  }
  .star.Four {
  	background-position: 0px -61px;
  }
  .star.Five {
  	background-position: 0px -75px;
  }
  .review_content {
    div {
     border:none;
    }
  }
  .review_votes {
    div {
      padding:0px;
    }
  }
  // Footer
  .footer_links {
    border-bottom:none;
    li {
      border-left:none;
      margin:0px;
      padding:0px;
    }
  }
  // Alerts
  .alert {
  /*  Position alerts at the bottom of the browser window*/
    position: static;
    width: auto;
    margin-bottom:0px;
  }
  // Carousel
  .es-carousel-wrapper {
    padding:0px;
    border:0px;
  }
  .es-carousel {
    border:0px;
    ul {
      display:block;
      li {
        float:none;
      }
    }
  }
}



// LANDSCAPE PHONE TO SMALL DESKTOP & PORTRAIT TABLET
// --------------------------------------------------

@media (max-width: 768px) {
  // GRID & CONTAINERS
  // -----------------
  // Remove width from containers
  .container {
    width: auto;
    padding: 0 20px;
  }
  // Fluid rows
  .row-fluid {
    width: 100%;
  }
  // Undo negative margin on rows
  .row {
    margin-left: 0;
  }
  // Make all columns even
  .row > [class*="span"],
  .row-fluid > [class*="span"] {
    float: none;
    display: block;
    width: auto;
    margin: 0;
  }
  .basket-title {
    display:none;
  }
  .basket-items {
    .pull-right {
      float:none;
    }
  }
}



// PORTRAIT TABLET TO DEFAULT DESKTOP
// ----------------------------------

@media (min-width: 768px) and (max-width: 980px) {

  // Fixed grid
  #gridSystem > .generate(12, 42px, 20px);

  // Fluid grid
  #fluidGridSystem > .generate(12, 5.801104972%, 2.762430939%);

  // Input grid
  #inputGridSystem > .generate(12, 42px, 20px);

}



// TABLETS AND BELOW
// -----------------
@media (max-width: 980px) {

  // UNFIX THE TOPBAR
  // ----------------
  // Remove any padding from the body
  body {
    padding-top: 0;
  }
  // Unfix the navbar
  .navbar-fixed-top {
    position: static;
    margin-bottom: @baseLineHeight;
  }
  .navbar-fixed-top .navbar-inner {
    padding: 5px;
  }
  .navbar .container {
    width: auto;
    padding: 0;
  }
  // Account for brand name
  .navbar .brand {
    padding-left: 10px;
    padding-right: 10px;
    margin: 0 0 0 -5px;
  }
  // Nav collapse clears brand
  .navbar .nav-collapse {
    clear: both;
  }
  // Block-level the nav
  .navbar .nav {
    float: none;
    margin: 0 0 (@baseLineHeight / 2);
  }
  .navbar .nav > li {
    float: none;
  }
  .navbar .nav > li > a {
    margin-bottom: 2px;
  }
  .navbar .nav > .divider-vertical {
    display: none;
  }
  // Nav and dropdown links in navbar
  .navbar .nav > li > a,
  .navbar .dropdown-menu a {
    padding: 6px 15px;
    font-weight: bold;
    color: @navbarLinkColor;
    .border-radius(3px);
  }
  .navbar .dropdown-menu li + li a {
    margin-bottom: 2px;
  }
  .navbar .nav > li > a:hover,
  .navbar .dropdown-menu a:hover {
    background-color: @navbarBackground;
  }
  // Dropdowns in the navbar
  .navbar .dropdown-menu {
    position: static;
    top: auto;
    left: auto;
    float: none;
    display: block;
    max-width: none;
    margin: 0 15px;
    padding: 0;
    background-color: transparent;
    border: none;
    .border-radius(0);
    .box-shadow(none);
  }
  .navbar .dropdown-menu:before,
  .navbar .dropdown-menu:after {
    display: none;
  }
  .navbar .dropdown-menu .divider {
    display: none;
  }
  // Forms in navbar
  .navbar-form,
  .navbar-search {
    float: none;
    padding: (@baseLineHeight / 2) 15px;
    margin: (@baseLineHeight / 2) 0;
    border-top: 1px solid @navbarBackground;
    border-bottom: 1px solid @navbarBackground;
    @shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.1);
    .box-shadow(@shadow);
  }
  // Pull right (secondary) nav content
  .navbar .nav.pull-right {
    float: none;
    margin-left: 0;
  }
  // Static navbar
  .navbar-static .navbar-inner {
    padding-left:  10px;
    padding-right: 10px;
  }
  // Navbar button
  .btn-navbar {
    display: block;
  }

  // Hide everything in the navbar save .brand and toggle button */
  .nav-collapse {
    overflow: hidden;
    height: 0;
  }
  // Header
  .header {
    text-shadow:none;
  }
  // Cart
  .cart, 
  h1.span6
   {
    display:none!important;
  }
  // Navbar Accounts
  .navbar.accounts {
    margin-bottom:0px;
    .brand.hidden {
      display: inline;
      padding:6px 10px;
      font-size:18px;
    }
    .nav.pull-right {
      float:right;
      margin-bottom:0px;
    }
    .nav > li {
      float:left;
      div {
        padding: 6px 15px;
      }
    }
  }
  // Navbar Primary
  .navbar.primary {
    margin-top:0px;
    .brand.hidden {
      display: inline;
      visibility: visible;
    }
    .navbar-inner {
      .border-radius(0px);
    }
  }
  .brand.hidden,
  .btn-cart.hidden {
    visibility: visible;
  }
  .btn-cart {
    color:#fff;
    line-height:12px;
    padding:7px 10px 6px;
    text-shadow: none;
    &:hover {
     color:#fff; 
    }
  }
  .navbar #browse {
    > a {
        display:none;
    }
    ul {
      width:auto!important;
    }
    li {
      border:none!important;
    }
    .dropdown-menu {
      margin: 0;
    }
    .nav.sub-nav {
      position:static;
      visibility:visible;
      li {
        a {
          padding: 6px 15px;
        }
      }
    }
  }
  #browse .dropdown-menu > li:hover .sub-nav,
  #browse .dropdown-menu > li > a:hover .sub-nav,
  #browse .dropdown-menu > li:hover {
    background:none;
    border:none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    -webkit-background-clip: none;
    -moz-background-clip: none;
    background-clip: none;
  }
}



// DEFAULT DESKTOP
// ---------------

@media (min-width: 980px) {
  .nav-collapse.collapse {
    height: auto !important;
  }
}



// LARGE DESKTOP & UP
// ------------------

@media (min-width: 1200px) {

  // Fixed grid
  #gridSystem > .generate(12, 70px, 30px);

  // Fluid grid
  #fluidGridSystem > .generate(12, 5.982905983%, 2.564102564%);

  // Input grid
  #inputGridSystem > .generate(12, 70px, 30px);

  // Thumbnails
  .thumbnails {
    margin-left: -30px;
  }
  .thumbnails > li {
    margin-left: 30px;
  }

}
