{% extends 'dashboard/reports/index.html' %}
{% load currency_filters %}
{% load i18n %}

{% block report %}
{% if objects %}
	<table class="table table-striped table-bordered">
		<tr>
			<th>{% trans "Offer" %}</th>
			<th>{% trans "Total discount" %}</th>
		</tr>
		{% for offer_discount in objects %}
		<tr>
			<td>{{ offer_discount.offer.name }}</td>
			<td>{{ offer_discount.total_discount|currency }}</td>
		</tr>
		{% endfor %}
	</table>
    {% if page_obj %}
        {% include "catalogue/partials/pagination.html" %}
    {% endif %}
{% else %}
<p>{% trans "No results found." %}</p>
{% endif %}
{% endblock %}
