{% extends 'dashboard/layout.html' %}
{% load i18n %}

{% block title %}
{% trans "Shipping address" %} | {% trans "Order" %} {{ order.number }} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
	<a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
	<a href="{% url dashboard:order-list %}">{% trans "Orders" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
		<a href="{% url dashboard:order-detail order.number %}">{{ order.number }}</a>
        <span class="divider">/</span>
    </li>
	<li class="active"><a href=".">{% trans "Edit shipping address" %}</a></li>
</ul>
{% endblock %}

{% block header %}
<div class="page-header">
	<h2>{% blocktrans %}Edit shipping address for order {{ order.number }}{% endblocktrans %}</h2>
</div>
{% endblock header %}

{% block content %}

<form action="." method="post" class="well form-horizontal">
	{% csrf_token %}
	{% include "partials/form_fields.html" with form=form %}
	<div class="form-actions">
		<button type="submit" class="btn btn-primary">{% trans "Update address" %}</button>
		or <a href="{% url dashboard:order-detail order.number %}">{% trans "cancel" %}</a>
	</div>
</form>

{% endblock content %}

