{% load i18n %}

<section class="well well-blank">
    <div class="sub-header">
        <h2>{{ promotion.name }}</h2>
    </div>
    <p>{{ promotion.description }}</p>

    <div class="es-carousel-wrapper">
        <div class="es-carousel">
            <ul class="products">
                {% for product in products %}
                <li>{% include "promotions/partials/product_carousel.html" %}</li>
                {% endfor %}
            </ul>
        </div>
    </div>

    {% if promotion.link_url %}
	<a href="{{ promotion.link_url }}">{{ promotion.link_text }}</a>
    {% endif %}
</section>


