{% extends "layout_2_col.html" %}
{% load i18n %}

{% block navigation %}
    {% include "partials/nav_alternate.html" %}
{% endblock %}

{% block column_left %}
{% endblock %}

{% block header %}
<div class="sub-header">
	<h2>{% trans "Welcome!" %}</h2>
</div>
{% endblock header %}


{% block content %}
{% endblock content %}

