{% extends 'dashboard/offers/step_form.html' %}
{% load i18n %}

{% block form_extradata %}
Ranges can be created and edited from within the 
<a href="{% url dashboard:range-list %}">range dashboard</a>.
{% endblock form_extradata %}
