{% extends 'dashboard/layout.html' %}
{% load currency_filters %}
{% load i18n %}

{% block title %}
{{ title }} | {% trans "Offer management" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
	<a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
	<a href="{% url dashboard:offer-list %}">{% trans "Offers" %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active"><a href=".">{{ title }}</a></li>
</ul>
{% endblock %}

{% block header %}
<div class="page-header">
	<h1>{{ title }}</h1>
</div>
{% endblock header %}

{% block dashboard_content %}
<form action="." method="post" class="form-horizontal well">
	{% csrf_token %}
	{% include "partials/form_fields.html" with form=form %}
	{% block form_extradata %}{% endblock %}
	{% block form_actions %}
	<div class="form-actions">
		{% if back_url %}
		<a href="{{ back_url }}" class="btn btn-primary">{% trans "Back" %}</a> {% trans "or" %}
		{% endif %}
		<button class="btn btn-primary" type="submit">{% trans "Continue" %}</button> {% trans "or" %}
		<a href="{% url dashboard:offer-list %}">{% trans "cancel" %}</a>
	</div>
	{% endblock form_actions %}
</form>
{% endblock dashboard_content %}
