{% extends 'layout.html' %}
{% load i18n %}

{% block title %}{% trans 'Password reset' %} | {{ block.super }}{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url promotions:home %}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active"><a href=".">{% trans 'Password reset' %}</a></li>
</ul>
{% endblock %}

{% block content %}

    <div class="sub-header">
        <h2>{% trans "Password reset" %}</h2>
    </div>

    <form id="password_reset_form" action="" method="post" class="form-stacked well">
    {% csrf_token %}

        <p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>

        <div class="control-group {% for error in form.email.errors %}error{% endfor %}">
            <label for="id_email" class="control-label {% if form.email.field.required %}required{% endif %}">{% trans 'E-mail address:' %}{% if form.email.field.required %} <span>*</span>{% endif %}</label>
            <div class="controls">
                {{ form.email }}
                {% for error in form.email.errors %}
                    <span class="help-block">
                        {{ error|escape }}
                    </span>
                {% endfor %}
            </div>
        </div>

        <div class="form-actions">
             <input type="submit" class="btn btn-primary" value="{% trans 'Reset my password' %}" />
        </div>

    </form>

{% endblock %}
