{% extends "layout.html" %}
{% load i18n %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url promotions:home %}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url customer:summary %}">{% trans 'Account' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active"><a href=".">{% trans 'Edit profile' %}</a></li>
</ul>
{% endblock %}


{% block title %}
{% trans 'Edit profile' %} | {{ block.super }}
{% endblock %}

{% block header %}
<div class="page-header">
    <h2>{% trans 'Edit profile' %}</h2>
</div>
{% endblock header %}


{% block content %}

<form action="." method="post">
    {% csrf_token %}
    {% include 'partials/form_fields.html' with form=form %}
    <div class="form-actions">
        <button type="submit" class="btn btn-primary">{% trans 'Save' %}</button>
        {% trans 'or' %} <a href="{% url customer:summary %}">{% trans 'cancel' %}</a>.
    </div>
</form>

{% endblock content %}
