/*!
 * Bootstrap v2.0.0
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */
// Feel free in including or removing style sheet as project demands.

// CSS Reset
@import "bootstrap/reset.less";

// Core variables and mixins
@import "bootstrap/variables.less"; // Modify this for custom colors, font-sizes, etc
@import "bootstrap/mixins.less";

// Oscar variables and mixins
@import "page/osc_mixins.less"; // Kept separtate for bootstrap updates - but should be imported into bootstap mixins.

// Grid system and page structure
@import "bootstrap/scaffolding.less";
@import "bootstrap/grid.less";
@import "bootstrap/layouts.less";

// Base CSS
@import "bootstrap/type.less";
@import "bootstrap/forms.less";
@import "bootstrap/tables.less";

// Components: common
@import "bootstrap/dropdowns.less";
@import "bootstrap/wells.less";
@import "bootstrap/component-animations.less";
@import "bootstrap/close.less";

// Components: Buttons & Alerts
@import "bootstrap/buttons.less";
@import "bootstrap/button-groups.less";
@import "bootstrap/alerts.less"; // Note: alerts share common CSS with buttons and thus have styles in buttons.less

// Components: Nav
@import "bootstrap/navs.less";
@import "bootstrap/navbar.less";
@import "bootstrap/breadcrumbs.less";
@import "bootstrap/pager.less";

// Components: Popovers
@import "bootstrap/modals.less";

// Components: Misc
@import "bootstrap/labels.less";
@import "bootstrap/carousel.less";
@import "bootstrap/hero-unit.less";

// Unique Page Styles
@import "page/osc_layout.less"; // Note: combine and remove with layout.less in bootstrap - it was kept separart on intital for bootstrap updates
@import "page/head_foot.less";
@import "page/account.less";
@import "page/checkout.less";
@import "page/product_lists.less";
@import "page/product_page.less";
@import "page/plugins.less";
@import "page/promotions.less";
@import "page/badges.less";

// Unique Fonts
@import url("snowcone.css"); 

// Utility classes
@import "bootstrap/utilities.less"; // Has to be last to override when necessary
