{% load i18n %}

{% if user.is_authenticated %}
{% trans "Is this review helpful?" %}<br/>
    <form action="{{ review.get_absolute_url }}" method="post" class="vote_agree" >
        {% csrf_token %}               
        <input type="hidden" name="delta" value="1"/>
		<button type="submit" class="btn btn-success btn-small">{% trans "Yes" %}</button>
    </form>
    <form  action="{{ review.get_absolute_url }}" method="post">
        {% csrf_token %}                
        <input type="hidden" name="delta" value="-1"/>
		<button type="submit" class="btn btn-small">{% trans "No" %}</button>
    </form>
{% endif %}