{% load currency_filters %}
{% load history_tags %}
{% load basket_tags %}
{% load i18n %}

<ul class="basket_item">
{% if request.basket.num_lines %}
    {% for line in basket.all_lines %}
    <li>
        <article>
            <h4><a href="{{ line.product.get_absolute_url }}">{{ line.description }}</a></h4>
			<p><strong>{% trans "Quantity:" %}</strong> <span>{{ line.quantity }}</span> x <span>{{ line.unit_price_excl_tax|currency }}</span></p>
        </article>
    </li>
    {% endfor %}
    <li class="form-actions">
	<h4><small>{% trans "Total Excl Tax:" %} {{ request.basket.total_excl_tax|currency }}</small> {% trans "Total:" %} {{ basket.total_incl_tax|currency }}</h4>
	<p><a href="{% url basket:summary %}" class="btn btn-info btn-small">{% trans "View Basket" %}</a></p>
	<p><a href="{% url checkout:index %}" class="btn btn-primary btn-small">{% trans "Checkout" %}</a></p>
    </li>
{% else %}
    <li>
	<p>{% trans "Your basket is empty, you should probably add some items to buy." %}</p>
    </li>
{% endif %}
</ul>
