{% extends "base.html" %}
{% load i18n %}

{% block extrahead %}
    <link rel="stylesheet" href="{{ STATIC_URL }}oscar/css/responsive.css" />
{% endblock %}

{% block layout %}
<div class="navbar accounts">
    <div class="navbar-inner">
        <div class="container-fluid">
            <a class="brand hidden" href="{% url promotions:home %}">{{ shop_name }}</a>
            <ul class="nav pull-right">
                <li><a href="#">{% trans 'Home' %}</a></li>
                <li><a href="#about">{% trans 'About' %}</a></li>
                <li><a href="#contact">{% trans 'Contact' %}</a></li>
                {% if user.is_authenticated %}
                    {% if user.is_staff %}
                    <li><a href="{% url dashboard:index %}">{% trans 'Dashboard' %}</a></li>
                    {% endif %}
                <li><a href="{% url customer:summary %}">{% trans 'Profile' %}</a></li>
                <li><a href="{% url customer:logout %}">{% trans 'Logout' %}</a></li>
                {% else %}
                <li><a href="{% url customer:login %}">{% trans 'Login' %}</a></li>
                {% endif %}
            </ul>
        </div>
    </div><!-- /navbar-inner -->
</div><!-- /navbar -->

<div class="container">
    <div class="hero-unit">
        <h1>{% trans 'Internal Server Error!' %}</h1>
        <p>{% trans "Something went terribly wrong.  We're very sorry and will fix this problem as soon as possible." %}</p>
        <p>
            <a class="btn btn-primary btn-large" onClick="javascript:history.go(-1);">{% trans 'Go back to previous page' %}</a>
        </p>
    </div>
</div>
{% endblock %}