{% if product %}
	<!-- Colorbox for image galleries -->
	<link rel="stylesheet" href="{{ STATIC_URL }}oscar/js/colorbox/colorbox.css" type="text/css" media="screen" charset="utf-8"/>
{% endif %}
<link rel="stylesheet" href="{{ STATIC_URL }}oscar/css/responsive.css" />