{% extends "layout.html" %}

{% load currency_filters %}

{% block header %}
<div class="page-header">
    <h1>{{ flatpage.title }}</h1>
</div>
{% endblock header %}

{% block flatpage %}
<article>
    {{ flatpage.content|linebreaks }}
</article>
{% endblock %}