// OSCAR PAGE STRUCTURE
// -----------
body {
  background-color: @grayLighter;
}
.container-fluid {
  //Unique styles
  padding:0px;
  margin:0px auto;
  max-width:960px;
}
.page {
  background:@white;
  -webkit-border-radius: 0 0 6px 6px;
  -moz-border-radius: 0 0 6px 6px;
  border-radius: 0 0 6px 6px;
  -webkit-box-shadow: 0 1px 2px rgba(0,0,0,.15);
  -moz-box-shadow: 0 1px 2px rgba(0,0,0,.15);
  box-shadow: 0 1px 2px rgba(0,0,0,.15);
}
.page_inner {
   padding:@gridGutterWidth;
   .clearfix();
}
// OSCAR NAV BAR MODIFICATIONS
// -----------
.navbar.primary {
  margin-bottom:0px;
  margin-top:@baseFontSize * 2;
  .brand.hidden {
    display: none;
  }
  .form-search {
    .btn {
      margin-top: 0px; // make buttons vertically centered in navbar
    }
  }
}
.navbar.accounts {
  margin-bottom:@baseFontSize * 4;
  .navbar-inner {
    .border-radius(inherit)
  }
}
// WELLS
// -----
.well {
  .clearfix();
}
.well-success {
  background-color: @successBackground;
  border-color: @successBorder;  
}
.well-danger {
  background-color: @errorBackground;
  border-color: @errorBorder;
}
.well-info {
  background-color: @infoBackground;
  border-color: @infoBorder;
}
.well-blank {
  background-color: @white;
  border-color: rgba(0,0,0,.1);
}
// UTILITY CLASSES
// ---------------
.pull-clear {
  clear: both;
}
// FORMS
// ------------
form {
  .clearfix();
}
.form-actions {
  .clearfix();
}
//For IE: adds width for selects inside overflow hidden containers
.select-open {
  width:300px!important;
}

// ADDITIONAL ERRORS
.errorlist {
    margin:0;
    padding:0 0 10px 0;
    color:#B94A48;
    li {
        padding:0 0 5px 0;
        list-style:none;
    }
}

.control-label.required span {
    color: #FF0000;
}